from _typeshed import Incomplete
from typing import Any

log: Any
SIGNATURE_HMAC_SHA1: str
SIGNATURE_HMAC_SHA256: str
SIGNATURE_HMAC_SHA512: str
SIGNATURE_HMAC: str
SIGNATURE_RSA_SHA1: str
SIGNATURE_RSA_SHA256: str
SIGNATURE_RSA_SHA512: str
SIGNATURE_RSA: str
SIGNATURE_PLAINTEXT: str
SIGNATURE_METHODS: Any
SIGNATURE_TYPE_AUTH_HEADER: str
SIGNATURE_TYPE_QUERY: str
SIGNATURE_TYPE_BODY: str
CONTENT_TYPE_FORM_URLENCODED: str

class Client:
    SIGNATURE_METHODS: Any
    @classmethod
    def register_signature_method(cls, method_name, method_callback) -> None: ...
    client_key: Any
    client_secret: Any
    resource_owner_key: Any
    resource_owner_secret: Any
    signature_method: Any
    signature_type: Any
    callback_uri: Any
    rsa_key: Any
    verifier: Any
    realm: Any
    encoding: Any
    decoding: Any
    nonce: Any
    timestamp: Any
    def __init__(
        self,
        client_key,
        client_secret: Incomplete | None = None,
        resource_owner_key: Incomplete | None = None,
        resource_owner_secret: Incomplete | None = None,
        callback_uri: Incomplete | None = None,
        signature_method="HMAC-SHA1",
        signature_type="AUTH_HEADER",
        rsa_key: Incomplete | None = None,
        verifier: Incomplete | None = None,
        realm: Incomplete | None = None,
        encoding: str = "utf-8",
        decoding: Incomplete | None = None,
        nonce: Incomplete | None = None,
        timestamp: Incomplete | None = None,
    ): ...
    def get_oauth_signature(self, request): ...
    def get_oauth_params(self, request): ...
    def sign(
        self,
        uri,
        http_method: str = "GET",
        body: Incomplete | None = None,
        headers: Incomplete | None = None,
        realm: Incomplete | None = None,
    ): ...



from networkx.algorithms.isomorphism.ismags import *
from networkx.algorithms.isomorphism.isomorph import *
from networkx.algorithms.isomorphism.matchhelpers import *
from networkx.algorithms.isomorphism.temporalisomorphvf2 import *
from networkx.algorithms.isomorphism.tree_isomorphism import *
from networkx.algorithms.isomorphism.vf2pp import *
from networkx.algorithms.isomorphism.vf2userfunc import *



from typing import Any

class Screen:
    def __init__(self) -> None: ...
    @property
    def screen_height(self) -> int: ...
    @property
    def screen_width(self) -> int: ...
    @staticmethod
    def clear() -> None: ...
    @staticmethod
    def flush() -> None: ...
    def input(self, prompt: str = "") -> str: ...
    @staticmethod
    def printf(*args: Any) -> None: ...
    @staticmethod
    def println(*args: Any) -> None: ...



import io
from _typeshed import Incomplete

class RESTResponseAsync(io.IOBase):
    aiohttp_response: Incomplete
    status: Incomplete
    reason: Incomplete
    data: Incomplete
    def __init__(self, resp, data) -> None: ...
    def getheaders(self): ...
    def getheader(self, name, default: Incomplete | None = None): ...

class RESTClientObjectAsync:
    proxy: Incomplete
    proxy_headers: Incomplete
    allow_redirects: Incomplete
    max_redirects: Incomplete
    pool_manager: Incomplete
    def __init__(self, configuration, pools_size: int = 4, maxsize: Incomplete | None = None, **kwargs) -> None: ...
    async def close(self) -> None: ...
    async def request(
        self,
        method,
        url,
        query_params: Incomplete | None = None,
        headers: Incomplete | None = None,
        body: Incomplete | None = None,
        post_params: Incomplete | None = None,
        _preload_content: bool = True,
        _request_timeout: Incomplete | None = None,
    ): ...
    async def GET(
        self,
        url,
        headers: Incomplete | None = None,
        query_params: Incomplete | None = None,
        _preload_content: bool = True,
        _request_timeout: Incomplete | None = None,
    ): ...
    async def HEAD(
        self,
        url,
        headers: Incomplete | None = None,
        query_params: Incomplete | None = None,
        _preload_content: bool = True,
        _request_timeout: Incomplete | None = None,
    ): ...
    async def OPTIONS(
        self,
        url,
        headers: Incomplete | None = None,
        query_params: Incomplete | None = None,
        post_params: Incomplete | None = None,
        body: Incomplete | None = None,
        _preload_content: bool = True,
        _request_timeout: Incomplete | None = None,
    ): ...
    async def DELETE(
        self,
        url,
        headers: Incomplete | None = None,
        query_params: Incomplete | None = None,
        body: Incomplete | None = None,
        _preload_content: bool = True,
        _request_timeout: Incomplete | None = None,
    ): ...
    async def POST(
        self,
        url,
        headers: Incomplete | None = None,
        query_params: Incomplete | None = None,
        post_params: Incomplete | None = None,
        body: Incomplete | None = None,
        _preload_content: bool = True,
        _request_timeout: Incomplete | None = None,
    ): ...
    async def PUT(
        self,
        url,
        headers: Incomplete | None = None,
        query_params: Incomplete | None = None,
        post_params: Incomplete | None = None,
        body: Incomplete | None = None,
        _preload_content: bool = True,
        _request_timeout: Incomplete | None = None,
    ): ...
    async def PATCH(
        self,
        url,
        headers: Incomplete | None = None,
        query_params: Incomplete | None = None,
        post_params: Incomplete | None = None,
        body: Incomplete | None = None,
        _preload_content: bool = True,
        _request_timeout: Incomplete | None = None,
    ): ...



from collections.abc import Mapping, Sequence
from io import BytesIO
from re import Pattern
from typing import Any

from waitress.adjustments import Adjustments
from waitress.receiver import ChunkedReceiver, FixedStreamReceiver
from waitress.utilities import Error

class ParsingError(Exception): ...
class TransferEncodingNotImplemented(Exception): ...

class HTTPRequestParser:
    completed: bool
    empty: bool
    expect_continue: bool
    headers_finished: bool
    header_plus: bytes
    chunked: bool
    content_length: int
    header_bytes_received: int
    body_bytes_received: int
    body_rcv: ChunkedReceiver | FixedStreamReceiver | None
    version: str
    error: Error | None
    connection_close: bool
    headers: Mapping[str, str]
    adj: Adjustments
    def __init__(self, adj: Adjustments) -> None: ...
    def received(self, data: bytes) -> int: ...
    first_line: str
    command: bytes
    url_scheme: str
    def parse_header(self, header_plus: bytes) -> None: ...
    def get_body_stream(self) -> BytesIO: ...
    def close(self) -> None: ...

def split_uri(uri: bytes) -> tuple[str, str, bytes, str, str]: ...
def get_header_lines(header: bytes) -> Sequence[bytes]: ...

first_line_re: Pattern[Any]

def crack_first_line(line: str) -> tuple[bytes, bytes, bytes]: ...



from collections.abc import Callable, Iterable
from datetime import timedelta
from hashlib import _Hash
from typing import Any

def long_to_bytes(n: int, blocksize: int | None = 0) -> bytes: ...
def long_to_base64(data: int, size: int | None = 0) -> bytes: ...
def int_arr_to_long(arr: Iterable[Any]) -> int: ...
def base64_to_long(data: str | bytes) -> int: ...
def calculate_at_hash(access_token: str, hash_alg: Callable[[bytes], _Hash]) -> str: ...
def base64url_decode(input: bytes) -> bytes: ...
def base64url_encode(input: bytes) -> bytes: ...
def timedelta_total_seconds(delta: timedelta) -> int: ...
def ensure_binary(s: str | bytes) -> bytes: ...



from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

@_dispatch
def degree_assortativity_coefficient(
    G, x: str = "out", y: str = "in", weight: Incomplete | None = None, nodes: Incomplete | None = None
): ...
@_dispatch
def degree_pearson_correlation_coefficient(
    G, x: str = "out", y: str = "in", weight: Incomplete | None = None, nodes: Incomplete | None = None
): ...
@_dispatch
def attribute_assortativity_coefficient(G, attribute, nodes: Incomplete | None = None): ...
@_dispatch
def numeric_assortativity_coefficient(G, attribute, nodes: Incomplete | None = None): ...



from _typeshed import Incomplete

class TemplateSummaryErrors:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        kind: Incomplete | None = None,
        reason: Incomplete | None = None,
        fields: Incomplete | None = None,
        indexes: Incomplete | None = None,
    ) -> None: ...
    @property
    def kind(self): ...
    @kind.setter
    def kind(self, kind) -> None: ...
    @property
    def reason(self): ...
    @reason.setter
    def reason(self, reason) -> None: ...
    @property
    def fields(self): ...
    @fields.setter
    def fields(self, fields) -> None: ...
    @property
    def indexes(self): ...
    @indexes.setter
    def indexes(self, indexes) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete
from collections.abc import Mapping
from typing import TypeVar, overload

from pandas import DataFrame
from pandas.core.interchange.dataframe_protocol import DataFrame as DataFrameProtocol
from seaborn._core.typing import DataSource, VariableSpec

_T = TypeVar("_T", Mapping[Incomplete, Incomplete], None)

class PlotData:
    frame: DataFrame
    frames: dict[tuple[str, str], DataFrame]
    names: dict[str, str | None]
    ids: dict[str, str | int]
    source_data: DataSource
    source_vars: dict[str, VariableSpec]
    def __init__(self, data: DataSource, variables: dict[str, VariableSpec]) -> None: ...
    def __contains__(self, key: str) -> bool: ...
    def join(self, data: DataSource, variables: dict[str, VariableSpec] | None) -> PlotData: ...

@overload
def handle_data_source(data: _T) -> _T: ...
@overload
def handle_data_source(data: DataFrameProtocol) -> DataFrame: ...
def convert_dataframe_to_pandas(data: object) -> DataFrame: ...



from _typeshed import Incomplete

from hvac.api.vault_api_base import VaultApiBase

logger: Incomplete

class Aws(VaultApiBase):
    def configure(
        self,
        max_retries: Incomplete | None = None,
        access_key: Incomplete | None = None,
        secret_key: Incomplete | None = None,
        endpoint: Incomplete | None = None,
        iam_endpoint: Incomplete | None = None,
        sts_endpoint: Incomplete | None = None,
        iam_server_id_header_value: Incomplete | None = None,
        mount_point: str = "aws",
    ): ...
    def read_config(self, mount_point: str = "aws"): ...
    def delete_config(self, mount_point: str = "aws"): ...
    def configure_identity_integration(
        self, iam_alias: Incomplete | None = None, ec2_alias: Incomplete | None = None, mount_point: str = "aws"
    ): ...
    def read_identity_integration(self, mount_point: str = "aws"): ...
    def create_certificate_configuration(
        self, cert_name, aws_public_cert, document_type: Incomplete | None = None, mount_point: str = "aws"
    ): ...
    def read_certificate_configuration(self, cert_name, mount_point: str = "aws"): ...
    def delete_certificate_configuration(self, cert_name, mount_point: str = "aws"): ...
    def list_certificate_configurations(self, mount_point: str = "aws"): ...
    def create_sts_role(self, account_id, sts_role, mount_point: str = "aws"): ...
    def read_sts_role(self, account_id, mount_point: str = "aws"): ...
    def list_sts_roles(self, mount_point: str = "aws"): ...
    def delete_sts_role(self, account_id, mount_point: str = "aws"): ...
    def configure_identity_whitelist_tidy(
        self, safety_buffer: Incomplete | None = None, disable_periodic_tidy: Incomplete | None = None, mount_point: str = "aws"
    ): ...
    def read_identity_whitelist_tidy(self, mount_point: str = "aws"): ...
    def delete_identity_whitelist_tidy(self, mount_point: str = "aws"): ...
    def configure_role_tag_blacklist_tidy(
        self, safety_buffer: Incomplete | None = None, disable_periodic_tidy: Incomplete | None = None, mount_point: str = "aws"
    ): ...
    def read_role_tag_blacklist_tidy(self, mount_point: str = "aws"): ...
    def delete_role_tag_blacklist_tidy(self, mount_point: str = "aws"): ...
    def create_role(
        self,
        role,
        auth_type: Incomplete | None = None,
        bound_ami_id: Incomplete | None = None,
        bound_account_id: Incomplete | None = None,
        bound_region: Incomplete | None = None,
        bound_vpc_id: Incomplete | None = None,
        bound_subnet_id: Incomplete | None = None,
        bound_iam_role_arn: Incomplete | None = None,
        bound_iam_instance_profile_arn: Incomplete | None = None,
        bound_ec2_instance_id: Incomplete | None = None,
        role_tag: Incomplete | None = None,
        bound_iam_principal_arn: Incomplete | None = None,
        inferred_entity_type: Incomplete | None = None,
        inferred_aws_region: Incomplete | None = None,
        resolve_aws_unique_ids: Incomplete | None = None,
        ttl: Incomplete | None = None,
        max_ttl: Incomplete | None = None,
        period: Incomplete | None = None,
        policies: Incomplete | None = None,
        allow_instance_migration: Incomplete | None = None,
        disallow_reauthentication: Incomplete | None = None,
        mount_point: str = "aws",
    ): ...
    def read_role(self, role, mount_point: str = "aws"): ...
    def list_roles(self, mount_point: str = "aws"): ...
    def delete_role(self, role, mount_point: str = "aws"): ...
    def create_role_tags(
        self,
        role,
        policies: Incomplete | None = None,
        max_ttl: Incomplete | None = None,
        instance_id: Incomplete | None = None,
        allow_instance_migration: Incomplete | None = None,
        disallow_reauthentication: Incomplete | None = None,
        mount_point: str = "aws",
    ): ...
    def iam_login(
        self,
        access_key,
        secret_key,
        session_token: Incomplete | None = None,
        header_value: Incomplete | None = None,
        role: Incomplete | None = None,
        use_token: bool = True,
        region: str = "us-east-1",
        mount_point: str = "aws",
    ): ...
    def ec2_login(
        self,
        pkcs7,
        nonce: Incomplete | None = None,
        role: Incomplete | None = None,
        use_token: bool = True,
        mount_point: str = "aws",
    ): ...
    def place_role_tags_in_blacklist(self, role_tag, mount_point: str = "aws"): ...
    def read_role_tag_blacklist(self, role_tag, mount_point: str = "aws"): ...
    def list_blacklist_tags(self, mount_point: str = "aws"): ...
    def delete_blacklist_tags(self, role_tag, mount_point: str = "aws"): ...
    def tidy_blacklist_tags(self, safety_buffer: str = "72h", mount_point: str = "aws"): ...
    def read_identity_whitelist(self, instance_id, mount_point: str = "aws"): ...
    def list_identity_whitelist(self, mount_point: str = "aws"): ...
    def delete_identity_whitelist_entries(self, instance_id, mount_point: str = "aws"): ...
    def tidy_identity_whitelist_entries(self, safety_buffer: str = "72h", mount_point: str = "aws"): ...



from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

@_dispatch
def katz_centrality(
    G,
    alpha: float = 0.1,
    beta: float = 1.0,
    max_iter: int = 1000,
    tol: float = 1e-06,
    nstart: Incomplete | None = None,
    normalized: bool = True,
    weight: Incomplete | None = None,
): ...
@_dispatch
def katz_centrality_numpy(
    G, alpha: float = 0.1, beta: float = 1.0, normalized: bool = True, weight: Incomplete | None = None
): ...



from _typeshed import Incomplete
from typing import ClassVar

from ..core import WesternCalendar

class MarshallIslands(WesternCalendar):
    FIXED_HOLIDAYS: Incomplete
    include_good_friday: ClassVar[bool]
    def get_variable_days(self, year): ...



from _typeshed import Incomplete

from antlr4.CommonTokenFactory import CommonTokenFactory as CommonTokenFactory
from antlr4.Lexer import TokenSource as TokenSource
from antlr4.Token import Token as Token

class ListTokenSource(TokenSource):
    tokens: Incomplete
    sourceName: Incomplete
    pos: int
    eofToken: Incomplete
    def __init__(self, tokens: list[Token], sourceName: str | None = None) -> None: ...
    @property
    def column(self): ...
    def nextToken(self): ...
    @property
    def line(self): ...
    def getInputStream(self): ...
    def getSourceName(self): ...



from _typeshed import Incomplete
from collections.abc import Generator

from networkx.utils.backends import _dispatch

@_dispatch
def bfs_beam_edges(G, source, value, width: Incomplete | None = None) -> Generator[Incomplete, Incomplete, Incomplete]: ...



from _typeshed import Incomplete

__all__ = ["TqdmCallback"]

# keras.callbacks.Callback
class _Callback:
    validation_data: Incomplete | None
    model: Incomplete | None
    params: Incomplete
    def __init__(self) -> None: ...
    def set_params(self, params) -> None: ...
    def set_model(self, model) -> None: ...
    def on_batch_begin(self, batch, logs: Incomplete | None = ...) -> None: ...
    def on_batch_end(self, batch, logs: Incomplete | None = ...) -> None: ...
    def on_epoch_begin(self, epoch, logs: Incomplete | None = ...) -> None: ...
    def on_epoch_end(self, epoch, logs: Incomplete | None = ...) -> None: ...
    def on_train_batch_begin(self, batch, logs: Incomplete | None = ...) -> None: ...
    def on_train_batch_end(self, batch, logs: Incomplete | None = ...) -> None: ...
    def on_test_batch_begin(self, batch, logs: Incomplete | None = ...) -> None: ...
    def on_test_batch_end(self, batch, logs: Incomplete | None = ...) -> None: ...
    def on_predict_batch_begin(self, batch, logs: Incomplete | None = ...) -> None: ...
    def on_predict_batch_end(self, batch, logs: Incomplete | None = ...) -> None: ...
    def on_train_begin(self, logs: Incomplete | None = ...) -> None: ...
    def on_train_end(self, logs: Incomplete | None = ...) -> None: ...
    def on_test_begin(self, logs: Incomplete | None = ...) -> None: ...
    def on_test_end(self, logs: Incomplete | None = ...) -> None: ...
    def on_predict_begin(self, logs: Incomplete | None = ...) -> None: ...
    def on_predict_end(self, logs: Incomplete | None = ...) -> None: ...

class TqdmCallback(_Callback):
    @staticmethod
    def bar2callback(bar, pop: Incomplete | None = None, delta=...): ...
    tqdm_class: Incomplete
    epoch_bar: Incomplete
    on_epoch_end: Incomplete
    batches: Incomplete
    verbose: Incomplete
    batch_bar: Incomplete
    on_batch_end: Incomplete
    def __init__(
        self,
        epochs: Incomplete | None = None,
        data_size: Incomplete | None = None,
        batch_size: Incomplete | None = None,
        verbose: int = 1,
        tqdm_class=...,
        **tqdm_kwargs,
    ) -> None: ...
    def on_train_begin(self, *_, **__) -> None: ...
    def on_epoch_begin(self, epoch, *_, **__) -> None: ...
    def on_train_end(self, *_, **__) -> None: ...
    def display(self) -> None: ...



from _typeshed import Incomplete

from hvac.api.vault_api_base import VaultApiBase

DEFAULT_MOUNT_POINT: str

class Okta(VaultApiBase):
    def configure(
        self,
        org_name,
        api_token: Incomplete | None = None,
        base_url: Incomplete | None = None,
        ttl: Incomplete | None = None,
        max_ttl: Incomplete | None = None,
        bypass_okta_mfa: Incomplete | None = None,
        mount_point="okta",
    ): ...
    def read_config(self, mount_point="okta"): ...
    def list_users(self, mount_point="okta"): ...
    def register_user(
        self, username, groups: Incomplete | None = None, policies: Incomplete | None = None, mount_point="okta"
    ): ...
    def read_user(self, username, mount_point="okta"): ...
    def delete_user(self, username, mount_point="okta"): ...
    def list_groups(self, mount_point="okta"): ...
    def register_group(self, name, policies: Incomplete | None = None, mount_point="okta"): ...
    def read_group(self, name, mount_point="okta"): ...
    def delete_group(self, name, mount_point="okta"): ...
    def login(self, username, password, use_token: bool = True, mount_point="okta"): ...



from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

@_dispatch
def color(G): ...
@_dispatch
def is_bipartite(G): ...
@_dispatch
def is_bipartite_node_set(G, nodes): ...
@_dispatch
def sets(G, top_nodes: Incomplete | None = None): ...
@_dispatch
def density(B, nodes): ...
@_dispatch
def degrees(B, nodes, weight: Incomplete | None = None): ...



from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

from .preflowpush import preflow_push

__all__ = ["maximum_flow", "maximum_flow_value", "minimum_cut", "minimum_cut_value"]

default_flow_func = preflow_push

@_dispatch
def maximum_flow(flowG, _s, _t, capacity: str = "capacity", flow_func: Incomplete | None = None, **kwargs): ...
@_dispatch
def maximum_flow_value(flowG, _s, _t, capacity: str = "capacity", flow_func: Incomplete | None = None, **kwargs): ...
@_dispatch
def minimum_cut(flowG, _s, _t, capacity: str = "capacity", flow_func: Incomplete | None = None, **kwargs): ...
@_dispatch
def minimum_cut_value(flowG, _s, _t, capacity: str = "capacity", flow_func: Incomplete | None = None, **kwargs): ...



from ...common import Request

class RequestValidator:
    def __init__(self) -> None: ...
    @property
    def allowed_signature_methods(self) -> tuple[str, ...]: ...
    @property
    def safe_characters(self) -> set[str]: ...
    @property
    def client_key_length(self) -> tuple[int, int]: ...
    @property
    def request_token_length(self) -> tuple[int, int]: ...
    @property
    def access_token_length(self) -> tuple[int, int]: ...
    @property
    def timestamp_lifetime(self) -> int: ...
    @property
    def nonce_length(self) -> tuple[int, int]: ...
    @property
    def verifier_length(self) -> tuple[int, int]: ...
    @property
    def realms(self) -> list[str]: ...
    @property
    def enforce_ssl(self) -> bool: ...
    def check_client_key(self, client_key: str) -> bool: ...
    def check_request_token(self, request_token: str) -> bool: ...
    def check_access_token(self, request_token: str) -> bool: ...
    def check_nonce(self, nonce: str) -> bool: ...
    def check_verifier(self, verifier: str) -> bool: ...
    def check_realms(self, realms: list[str]) -> bool: ...
    @property
    def dummy_client(self) -> str: ...
    @property
    def dummy_request_token(self) -> str: ...
    @property
    def dummy_access_token(self) -> str: ...
    def get_client_secret(self, client_key: str, request: Request) -> str: ...
    def get_request_token_secret(self, client_key: str, token: str, request: Request) -> str: ...
    def get_access_token_secret(self, client_key: str, token: str, request: Request) -> str: ...
    def get_default_realms(self, client_key: str, request: Request) -> list[str]: ...
    def get_realms(self, token: str, request: Request) -> list[str]: ...
    def get_redirect_uri(self, token: str, request: Request) -> str: ...
    def get_rsa_key(self, client_key: str, request: Request) -> str: ...
    def invalidate_request_token(self, client_key: str, request_token: str, request: Request) -> None: ...
    def validate_client_key(self, client_key: str, request: Request) -> bool: ...
    def validate_request_token(self, client_key: str, token: str, request: Request) -> bool: ...
    def validate_access_token(self, client_key: str, token: str, request: Request) -> bool: ...
    def validate_timestamp_and_nonce(
        self,
        client_key: str,
        timestamp,
        nonce: str,
        request: Request,
        request_token: str | None = None,
        access_token: str | None = None,
    ) -> bool: ...
    def validate_redirect_uri(self, client_key: str, redirect_uri, request: Request) -> bool: ...
    def validate_requested_realms(self, client_key: str, realms: list[str], request: Request) -> bool: ...
    def validate_realms(
        self, client_key: str, token: str, request: Request, uri: str | None = None, realms: list[str] | None = None
    ) -> bool: ...
    def validate_verifier(self, client_key: str, token: str, verifier: str, request: Request) -> bool: ...
    def verify_request_token(self, token: str, request: Request) -> bool: ...
    def verify_realms(self, token: str, realms: list[str], request: Request) -> bool: ...
    def save_access_token(self, token: str, request: Request) -> None: ...
    def save_request_token(self, token: str, request: Request) -> None: ...
    def save_verifier(self, token: str, verifier, request: Request) -> None: ...



from collections.abc import Iterable, Iterator

from ._pygit2 import Oid
from .callbacks import RemoteCallbacks
from .enums import SubmoduleIgnore, SubmoduleStatus
from .repository import BaseRepository, Repository

class Submodule:
    def __del__(self) -> None: ...
    def open(self) -> Repository: ...
    def init(self, overwrite: bool = False) -> None: ...
    def update(self, init: bool = False, callbacks: RemoteCallbacks | None = None) -> None: ...
    def reload(self, force: bool = False) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def path(self) -> str: ...
    @property
    def url(self) -> str: ...
    @property
    def branch(self) -> str: ...
    @property
    def head_id(self) -> Oid: ...

class SubmoduleCollection:
    def __init__(self, repository: BaseRepository) -> None: ...
    def __getitem__(self, name: str) -> Submodule: ...
    def __contains__(self, name: str) -> bool: ...
    def __iter__(self) -> Iterator[Submodule]: ...
    def get(self, name: str) -> Submodule | None: ...
    def add(self, url: str, path: str, link: bool = True, callbacks: RemoteCallbacks | None = None) -> Submodule: ...
    def init(self, submodules: Iterable[str] | None = None, overwrite: bool = False) -> None: ...
    def update(
        self, submodules: Iterable[str] | None = None, init: bool = False, callbacks: RemoteCallbacks | None = None
    ) -> None: ...
    def status(self, name: str, ignore: SubmoduleIgnore = ...) -> SubmoduleStatus: ...
    def cache_all(self) -> None: ...
    def cache_clear(self) -> None: ...



from _typeshed import Incomplete

# Cannot type most things here as DefusedExpatParser is based off of
# xml.sax.expatreader, which is an undocumented module and lacks types at the moment.

__origin__: str

DefusedExpatParser = Incomplete

def create_parser(*args, **kwargs): ...



from collections.abc import Callable
from typing_extensions import Self

from gevent.hub import Hub

class AbstractLinkable:
    @property
    def hub(self) -> Hub | None: ...
    def __init__(self, hub: Hub | None = None) -> None: ...
    def linkcount(self) -> int: ...
    def rawlink(self, callback: Callable[[Self], object], /) -> None: ...
    def ready(self) -> bool: ...
    def unlink(self, callback: Callable[[Self], object], /) -> None: ...



from _typeshed import Incomplete
from typing import Any

class OAuth2Token(dict[Any, Any]):
    def __init__(self, params, old_scope: Incomplete | None = None) -> None: ...
    @property
    def scope_changed(self): ...
    @property
    def old_scope(self): ...
    @property
    def old_scopes(self): ...
    @property
    def scope(self): ...
    @property
    def scopes(self): ...
    @property
    def missing_scopes(self): ...
    @property
    def additional_scopes(self): ...

def prepare_mac_header(
    token,
    uri,
    key,
    http_method,
    nonce: Incomplete | None = None,
    headers: Incomplete | None = None,
    body: Incomplete | None = None,
    ext: str = "",
    hash_algorithm: str = "hmac-sha-1",
    issue_time: Incomplete | None = None,
    draft: int = 0,
): ...
def prepare_bearer_uri(token, uri): ...
def prepare_bearer_headers(token, headers: Incomplete | None = None): ...
def prepare_bearer_body(token, body: str = ""): ...
def random_token_generator(request, refresh_token: bool = False): ...
def signed_token_generator(private_pem, **kwargs): ...
def get_token_from_header(request): ...

class TokenBase:
    def __call__(self, request, refresh_token: bool = False) -> None: ...
    def validate_request(self, request) -> None: ...
    def estimate_type(self, request) -> None: ...

class BearerToken(TokenBase):
    request_validator: Any
    token_generator: Any
    refresh_token_generator: Any
    expires_in: Any
    def __init__(
        self,
        request_validator: Incomplete | None = None,
        token_generator: Incomplete | None = None,
        expires_in: Incomplete | None = None,
        refresh_token_generator: Incomplete | None = None,
    ) -> None: ...
    def create_token(self, request, refresh_token: bool = False, **kwargs): ...
    def validate_request(self, request): ...
    def estimate_type(self, request): ...



from _typeshed import Incomplete

from ...extend.operation import ExtendedOperation
from ...protocol.rfc3062 import PasswdModifyRequestValue, PasswdModifyResponseValue

class ModifyPassword(ExtendedOperation):
    request_name: str
    request_value: PasswdModifyRequestValue
    asn1_spec: PasswdModifyResponseValue
    response_attribute: str
    def config(self) -> None: ...
    def __init__(
        self,
        connection,
        user: Incomplete | None = None,
        old_password: Incomplete | None = None,
        new_password: Incomplete | None = None,
        hash_algorithm: Incomplete | None = None,
        salt: Incomplete | None = None,
        controls: Incomplete | None = None,
    ) -> None: ...
    def populate_result(self) -> None: ...



from _typeshed import Incomplete

class ClientToken:
    @staticmethod
    def generate(params: Incomplete | None = None, gateway: Incomplete | None = None): ...
    @staticmethod
    def generate_signature(): ...



import contextlib
from _typeshed import ConvertibleToInt
from collections.abc import Callable, Iterable, Sequence
from datetime import datetime
from typing import Final, NamedTuple, SupportsIndex, SupportsInt, TypeVar
from typing_extensions import ParamSpec, TypeAlias

from pyscreeze import (
    center as center,
    locate as locate,
    locateAll as locateAll,
    locateAllOnScreen as locateAllOnScreen,
    locateCenterOnScreen as locateCenterOnScreen,
    locateOnScreen as locateOnScreen,
    locateOnWindow as locateOnWindow,
    pixel as pixel,
    pixelMatchesColor as pixelMatchesColor,
    screenshot as screenshot,
)

_P = ParamSpec("_P")
_R = TypeVar("_R")
# Explicitly mentioning str despite being in the ConvertibleToInt Alias because it has a different meaning (filename on screen)
# Specifying non-None Y arg when X is a string or sequence raises an error
# TODO: This could be better represented through overloads
_NormalizeableXArg: TypeAlias = str | ConvertibleToInt | Sequence[ConvertibleToInt]

# Constants
KEY_NAMES: list[str]
KEYBOARD_KEYS: list[str]
LEFT: Final = "left"
MIDDLE: Final = "middle"
RIGHT: Final = "right"
PRIMARY: Final = "primary"
SECONDARY: Final = "secondary"
G_LOG_SCREENSHOTS_FILENAMES: list[str]
# Implementation details
QWERTY: Final[str]
QWERTZ: Final[str]
MINIMUM_SLEEP: Final[float]

# These are meant to be overridable
LOG_SCREENSHOTS: bool
LOG_SCREENSHOTS_LIMIT: int | None
# https://pyautogui.readthedocs.io/en/latest/index.html#fail-safes
FAILSAFE: bool
PAUSE: float
DARWIN_CATCH_UP_TIME: float
FAILSAFE_POINTS: list[tuple[int, int]]
# https://pyautogui.readthedocs.io/en/latest/mouse.htmln#mouse-movement
MINIMUM_DURATION: float

class PyAutoGUIException(Exception): ...
class FailSafeException(PyAutoGUIException): ...
class ImageNotFoundException(PyAutoGUIException): ...

def raisePyAutoGUIImageNotFoundException(wrappedFunction: Callable[_P, _R]) -> Callable[_P, _R]: ...
def mouseInfo() -> None: ...
def useImageNotFoundException(value: bool | None = None) -> None: ...
def isShiftCharacter(character: str) -> bool: ...

class Point(NamedTuple):
    x: float
    y: float

class Size(NamedTuple):
    width: int
    height: int

def getPointOnLine(x1: float, y1: float, x2: float, y2: float, n: float) -> tuple[float, float]: ...
def linear(n: float) -> float: ...
def position(x: int | None = None, y: int | None = None) -> Point: ...
def size() -> Size: ...

resolution = size

def onScreen(x: _NormalizeableXArg | None, y: SupportsInt | None = None) -> bool: ...
def mouseDown(
    x: _NormalizeableXArg | None = None,
    y: SupportsInt | None = None,
    # Docstring says `button` can also be `int`, but `.lower()` is called unconditionally in `_normalizeButton()`
    button: str = "primary",
    duration: float = 0.0,
    tween: Callable[[float], float] = ...,
    logScreenshot: bool | None = None,
    _pause: bool = True,
) -> None: ...
def mouseUp(
    x: _NormalizeableXArg | None = None,
    y: SupportsInt | None = None,
    # Docstring says `button` can also be `int`, but `.lower()` is called unconditionally in `_normalizeButton()`
    button: str = "primary",
    duration: float = 0.0,
    tween: Callable[[float], float] = ...,
    logScreenshot: bool | None = None,
    _pause: bool = True,
) -> None: ...
def click(
    x: _NormalizeableXArg | None = None,
    y: SupportsInt | None = None,
    clicks: SupportsIndex = 1,
    interval: float = 0.0,
    # Docstring says `button` can also be `int`, but `.lower()` is called unconditionally in `_normalizeButton()`
    button: str = "primary",
    duration: float = 0.0,
    tween: Callable[[float], float] = ...,
    logScreenshot: bool | None = None,
    _pause: bool = True,
) -> None: ...
def leftClick(
    x: _NormalizeableXArg | None = None,
    y: SupportsInt | None = None,
    interval: float = 0.0,
    duration: float = 0.0,
    tween: Callable[[float], float] = ...,
    logScreenshot: bool | None = None,
    _pause: bool = True,
) -> None: ...
def rightClick(
    x: _NormalizeableXArg | None = None,
    y: SupportsInt | None = None,
    interval: float = 0.0,
    duration: float = 0.0,
    tween: Callable[[float], float] = ...,
    logScreenshot: bool | None = None,
    _pause: bool = True,
) -> None: ...
def middleClick(
    x: _NormalizeableXArg | None = None,
    y: SupportsInt | None = None,
    interval: float = 0.0,
    duration: float = 0.0,
    tween: Callable[[float], float] = ...,
    logScreenshot: bool | None = None,
    _pause: bool = True,
) -> None: ...
def doubleClick(
    x: _NormalizeableXArg | None = None,
    y: SupportsInt | None = None,
    interval: float = 0.0,
    # Docstring says `button` can also be `int`, but `.lower()` is called unconditionally in `_normalizeButton()`
    button: str = "left",
    duration: float = 0.0,
    tween: Callable[[float], float] = ...,
    logScreenshot: bool | None = None,
    _pause: bool = True,
) -> None: ...
def tripleClick(
    x: _NormalizeableXArg | None = None,
    y: SupportsInt | None = None,
    interval: float = 0.0,
    # Docstring says `button` can also be `int`, but `.lower()` is called unconditionally in `_normalizeButton()`
    button: str = "left",
    duration: float = 0.0,
    tween: Callable[[float], float] = ...,
    logScreenshot: bool | None = None,
    _pause: bool = True,
) -> None: ...
def scroll(
    clicks: float,
    x: _NormalizeableXArg | None = None,
    y: SupportsInt | None = None,
    logScreenshot: bool | None = None,
    _pause: bool = True,
) -> None: ...
def hscroll(
    clicks: float,
    x: _NormalizeableXArg | None = None,
    y: SupportsInt | None = None,
    logScreenshot: bool | None = None,
    _pause: bool = True,
) -> None: ...
def vscroll(
    clicks: float,
    x: _NormalizeableXArg | None = None,
    y: SupportsInt | None = None,
    logScreenshot: bool | None = None,
    _pause: bool = True,
) -> None: ...
def moveTo(
    x: _NormalizeableXArg | None = None,
    y: SupportsInt | None = None,
    duration: float = 0.0,
    tween: Callable[[float], float] = ...,
    logScreenshot: bool = False,
    _pause: bool = True,
) -> None: ...
def moveRel(
    xOffset: _NormalizeableXArg | None = None,
    yOffset: SupportsInt | None = None,
    duration: float = 0.0,
    tween: Callable[[float], float] = ...,
    logScreenshot: bool = False,
    _pause: bool = True,
) -> None: ...

move = moveRel

def dragTo(
    x: _NormalizeableXArg | None = None,
    y: SupportsInt | None = None,
    duration: float = 0.0,
    tween: Callable[[float], float] = ...,
    # Docstring says `button` can also be `int`, but `.lower()` is called unconditionally in `_normalizeButton()`
    button: str = "primary",
    logScreenshot: bool | None = None,
    _pause: bool = True,
    mouseDownUp: bool = True,
) -> None: ...
def dragRel(
    xOffset: _NormalizeableXArg | None = 0,
    yOffset: SupportsInt | None = 0,
    duration: float = 0.0,
    tween: Callable[[float], float] = ...,
    # Docstring says `button` can also be `int`, but `.lower()` is called unconditionally in `_normalizeButton()`
    button: str = "primary",
    logScreenshot: bool | None = None,
    _pause: bool = True,
    mouseDownUp: bool = True,
) -> None: ...

drag = dragRel

def isValidKey(key: str) -> bool: ...
def keyDown(key: str, logScreenshot: bool | None = None, _pause: bool = True) -> None: ...
def keyUp(key: str, logScreenshot: bool | None = None, _pause: bool = True) -> None: ...
def press(
    keys: str | Iterable[str],
    presses: SupportsIndex = 1,
    interval: float = 0.0,
    logScreenshot: bool | None = None,
    _pause: bool = True,
) -> None: ...
def hold(
    keys: str | Iterable[str], logScreenshot: bool | None = None, _pause: bool = True
) -> contextlib._GeneratorContextManager[None]: ...
def typewrite(
    message: str | Sequence[str], interval: float = 0.0, logScreenshot: bool | None = None, _pause: bool = True
) -> None: ...

write = typewrite

def hotkey(*args: str, logScreenshot: bool | None = None, interval: float = 0.0) -> None: ...

shortcut = hotkey

def failSafeCheck() -> None: ...
def displayMousePosition(xOffset: float = 0, yOffset: float = 0) -> None: ...
def sleep(seconds: float) -> None: ...
def countdown(seconds: SupportsIndex) -> None: ...
def run(commandStr: str, _ssCount: Sequence[int] | None = None) -> None: ...
def printInfo(dontPrint: bool = False) -> str: ...
def getInfo() -> tuple[str, str, str, str, Size, datetime]: ...



from _typeshed import Incomplete

from pika.adapters import base_connection

LOGGER: Incomplete

class TornadoConnection(base_connection.BaseConnection):
    def __init__(
        self,
        parameters: Incomplete | None = ...,
        on_open_callback: Incomplete | None = ...,
        on_open_error_callback: Incomplete | None = ...,
        on_close_callback: Incomplete | None = ...,
        custom_ioloop: Incomplete | None = ...,
        internal_connection_workflow: bool = ...,
    ) -> None: ...
    @classmethod
    def create_connection(
        cls, connection_configs, on_done, custom_ioloop: Incomplete | None = ..., workflow: Incomplete | None = ...
    ): ...



from _typeshed import Incomplete
from typing import Any

def BuildMessageAndEnumDescriptors(file_des: Incomplete, module: dict[str, Any]) -> None: ...
def BuildTopDescriptorsAndMessages(file_des: Incomplete, module_name: str, module: dict[str, Any]) -> None: ...



from _typeshed import Incomplete
from typing import Any

from oauthlib.oauth2.rfc6749.endpoints import (
    AuthorizationEndpoint as AuthorizationEndpoint,
    IntrospectEndpoint as IntrospectEndpoint,
    ResourceEndpoint as ResourceEndpoint,
    RevocationEndpoint as RevocationEndpoint,
    TokenEndpoint as TokenEndpoint,
)

from .userinfo import UserInfoEndpoint as UserInfoEndpoint

class Server(AuthorizationEndpoint, IntrospectEndpoint, TokenEndpoint, ResourceEndpoint, RevocationEndpoint, UserInfoEndpoint):
    auth_grant: Any
    implicit_grant: Any
    password_grant: Any
    credentials_grant: Any
    refresh_grant: Any
    openid_connect_auth: Any
    openid_connect_implicit: Any
    openid_connect_hybrid: Any
    bearer: Any
    jwt: Any
    auth_grant_choice: Any
    implicit_grant_choice: Any
    token_grant_choice: Any
    def __init__(
        self,
        request_validator,
        token_expires_in: Incomplete | None = None,
        token_generator: Incomplete | None = None,
        refresh_token_generator: Incomplete | None = None,
        *args,
        **kwargs,
    ) -> None: ...



import sys

__all__ = ["tomllib"]

if sys.version_info >= (3, 11):
    import tomllib
else:
    # This is actually vendored
    import tomli as tomllib  # type: ignore[import-not-found] # pyright: ignore[reportMissingImports]



from collections.abc import Sequence

from docutils.parsers.rst import Directive

class Contents(Directive):
    backlinks_values: Sequence[str]

class Sectnum(Directive): ...
class Header(Directive): ...
class Footer(Directive): ...



from _typeshed import Incomplete
from typing import Any

log: Any

class Dispatcher:
    default_grant: Any
    oidc_grant: Any

class AuthorizationCodeGrantDispatcher(Dispatcher):
    default_grant: Any
    oidc_grant: Any
    def __init__(self, default_grant: Incomplete | None = None, oidc_grant: Incomplete | None = None) -> None: ...
    def create_authorization_response(self, request, token_handler): ...
    def validate_authorization_request(self, request): ...

class ImplicitTokenGrantDispatcher(Dispatcher):
    default_grant: Any
    oidc_grant: Any
    def __init__(self, default_grant: Incomplete | None = None, oidc_grant: Incomplete | None = None) -> None: ...
    def create_authorization_response(self, request, token_handler): ...
    def validate_authorization_request(self, request): ...

class AuthorizationTokenGrantDispatcher(Dispatcher):
    default_grant: Any
    oidc_grant: Any
    request_validator: Any
    def __init__(
        self, request_validator, default_grant: Incomplete | None = None, oidc_grant: Incomplete | None = None
    ) -> None: ...
    def create_token_response(self, request, token_handler): ...



from _typeshed import Incomplete

class StatusRule:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        current_level: Incomplete | None = None,
        previous_level: Incomplete | None = None,
        count: Incomplete | None = None,
        period: Incomplete | None = None,
    ) -> None: ...
    @property
    def current_level(self): ...
    @current_level.setter
    def current_level(self, current_level) -> None: ...
    @property
    def previous_level(self): ...
    @previous_level.setter
    def previous_level(self, previous_level) -> None: ...
    @property
    def count(self): ...
    @count.setter
    def count(self, count) -> None: ...
    @property
    def period(self): ...
    @period.setter
    def period(self, period) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

from braintree.resource import Resource

class PartnerMerchant(Resource):
    partner_merchant_id: Incomplete
    private_key: Incomplete
    public_key: Incomplete
    merchant_public_id: Incomplete
    client_side_encryption_key: Incomplete
    def __init__(self, gateway, attributes) -> None: ...



from _typeshed import Incomplete

class RoutesSystem:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self, metrics: Incomplete | None = None, debug: Incomplete | None = None, health: Incomplete | None = None
    ) -> None: ...
    @property
    def metrics(self): ...
    @metrics.setter
    def metrics(self, metrics) -> None: ...
    @property
    def debug(self): ...
    @debug.setter
    def debug(self, debug) -> None: ...
    @property
    def health(self): ...
    @health.setter
    def health(self, health) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



import sys
from _typeshed import FileDescriptor
from typing import NamedTuple

import gevent.libuv.watcher as watcher
from gevent._ffi.loop import AbstractLoop
from gevent._types import _IoWatcher

def get_version() -> str: ...
def get_header_version() -> str: ...
def supported_backends() -> list[str]: ...

class loop(AbstractLoop):
    CALLBACK_CHECK_COUNT: int
    SIGNAL_CHECK_INTERVAL_MS: int
    approx_timer_resolution: float
    error_handler: None
    def __init__(self, flags: int | None = None, default: bool | None = None) -> None: ...

    class _HandleState(NamedTuple):
        handle: int
        type: str
        watcher: watcher.watcher
        ref: bool
        active: bool
        closing: bool

    def debug(self) -> list[_HandleState]: ...
    def install_sigchld(self) -> None: ...
    def reset_sigchld(self) -> None: ...
    # this returns a class private to gevent.libuv.watcher.io, which satisifies the protocol
    def io(self, fd: FileDescriptor, events: int, ref: bool = True, priority: int | None = None) -> _IoWatcher: ...
    def closing_fd(self, fd: FileDescriptor) -> bool: ...
    def timer(self, after: float, repeat: float = 0.0, ref: bool = True, priority: int | None = None) -> watcher.timer: ...
    def signal(self, signum: int, ref: bool = True, priority: int | None = None) -> watcher.signal: ...
    def idle(self, ref: bool = True, priority: int | None = None) -> watcher.idle: ...
    def check(self, ref: bool = True, priority: int | None = None) -> watcher.check: ...
    def async_(self, ref: bool = True, priority: int | None = None) -> watcher.async_: ...
    if sys.platform != "win32":
        def fork(self, ref: bool = True, priority: int | None = None) -> watcher.fork: ...
        def child(self, pid: int, trace: int = 0, ref: bool = True) -> watcher.child: ...
    # prepare is not supported on libuv yet, but we need type_error to annotate that



from _typeshed import Incomplete
from collections.abc import Iterable, Iterator
from typing import ClassVar, TypedDict
from typing_extensions import Self

from pkg_resources import Environment

from .. import Command, SetuptoolsDeprecationWarning

__all__ = ["easy_install", "PthDistributions", "extract_wininst_cfg", "get_exe_prefixes"]

class easy_install(Command):
    description: str
    command_consumes_arguments: bool
    user_options: Incomplete
    boolean_options: Incomplete
    negative_opt: Incomplete
    create_index: Incomplete
    user: int
    zip_ok: Incomplete
    install_dir: Incomplete
    index_url: Incomplete
    find_links: Incomplete
    build_directory: Incomplete
    args: Incomplete
    optimize: Incomplete
    upgrade: Incomplete
    editable: Incomplete
    root: Incomplete
    version: Incomplete
    install_purelib: Incomplete
    install_platlib: Incomplete
    install_headers: Incomplete
    install_lib: Incomplete
    install_scripts: Incomplete
    install_data: Incomplete
    install_base: Incomplete
    install_platbase: Incomplete
    install_userbase: Incomplete
    install_usersite: Incomplete
    no_find_links: Incomplete
    package_index: Incomplete
    pth_file: Incomplete
    site_dirs: Incomplete
    installed_projects: Incomplete
    verbose: Incomplete
    def initialize_options(self) -> None: ...
    def delete_blockers(self, blockers) -> None: ...
    config_vars: Incomplete
    script_dir: Incomplete
    all_site_dirs: Incomplete
    shadow_path: Incomplete
    local_index: Incomplete
    outputs: Incomplete
    def finalize_options(self) -> None: ...
    def expand_basedirs(self) -> None: ...
    def expand_dirs(self) -> None: ...
    def run(self, show_deprecation: bool = True) -> None: ...
    def pseudo_tempname(self): ...
    def warn_deprecated_options(self) -> None: ...
    def check_site_dir(self) -> None: ...
    def cant_write_to_target(self) -> None: ...
    def check_pth_processing(self): ...
    def install_egg_scripts(self, dist) -> None: ...
    def add_output(self, path) -> None: ...
    def not_editable(self, spec) -> None: ...
    def check_editable(self, spec) -> None: ...
    def easy_install(self, spec, deps: bool = False): ...
    def install_item(self, spec, download, tmpdir, deps, install_needed: bool = False): ...
    def select_scheme(self, name) -> None: ...
    def process_distribution(self, requirement, dist, deps: bool = True, *info) -> None: ...
    def should_unzip(self, dist): ...
    def maybe_move(self, spec, dist_filename, setup_base): ...
    def install_wrapper_scripts(self, dist) -> None: ...
    def install_script(self, dist, script_name, script_text, dev_path: Incomplete | None = None) -> None: ...
    def write_script(self, script_name, contents, mode: str = "t", blockers=()) -> None: ...
    def install_eggs(self, spec, dist_filename, tmpdir): ...
    def egg_distribution(self, egg_path): ...
    def install_egg(self, egg_path, tmpdir): ...
    def install_exe(self, dist_filename, tmpdir): ...
    def exe_to_egg(self, dist_filename, egg_tmp): ...
    def install_wheel(self, wheel_path, tmpdir): ...
    def installation_report(self, req, dist, what: str = "Installed"): ...
    def report_editable(self, spec, setup_script): ...
    def run_setup(self, setup_script, setup_base, args) -> None: ...
    def build_and_install(self, setup_script, setup_base): ...
    def update_pth(self, dist) -> None: ...
    def unpack_progress(self, src, dst): ...
    def unpack_and_compile(self, egg_path, destination): ...
    def byte_compile(self, to_compile) -> None: ...
    def create_home_path(self) -> None: ...
    INSTALL_SCHEMES: Incomplete
    DEFAULT_SCHEME: Incomplete

def extract_wininst_cfg(dist_filename): ...
def get_exe_prefixes(exe_filename): ...

class PthDistributions(Environment):
    dirty: bool
    filename: Incomplete
    sitedirs: Incomplete
    basedir: Incomplete
    paths: list[str]
    def __init__(self, filename, sitedirs=()) -> None: ...
    def save(self) -> None: ...
    def add(self, dist) -> None: ...
    def remove(self, dist) -> None: ...
    def make_relative(self, path): ...

class RewritePthDistributions(PthDistributions):
    prelude: Incomplete
    postlude: Incomplete

class _SplitArgs(TypedDict, total=False):
    comments: bool
    posix: bool

class CommandSpec(list[str]):
    options: list[str]
    split_args: ClassVar[_SplitArgs]
    @classmethod
    def best(cls) -> type[CommandSpec]: ...
    @classmethod
    def from_param(cls, param: str | Self | Iterable[str] | None) -> Self: ...
    @classmethod
    def from_environment(cls) -> CommandSpec: ...
    @classmethod
    def from_string(cls, string: str) -> CommandSpec: ...
    def install_options(self, script_text: str) -> None: ...
    def as_header(self) -> str: ...

class WindowsCommandSpec(CommandSpec): ...

class ScriptWriter:
    template: ClassVar[str]
    command_spec_class: ClassVar[type[CommandSpec]]
    @classmethod
    def get_args(cls, dist, header: Incomplete | None = None) -> Iterator[tuple[str, str]]: ...
    @classmethod
    def best(cls) -> type[ScriptWriter]: ...
    @classmethod
    def get_header(cls, script_text: str = "", executable: str | CommandSpec | Iterable[str] | None = None) -> str: ...

class WindowsScriptWriter(ScriptWriter):
    command_spec_class: ClassVar[type[WindowsCommandSpec]]
    @classmethod
    def best(cls) -> type[WindowsScriptWriter]: ...

class WindowsExecutableLauncherWriter(WindowsScriptWriter): ...
class EasyInstallDeprecationWarning(SetuptoolsDeprecationWarning): ...



from collections.abc import Callable, Generator, Iterable
from html.parser import HTMLParser
from typing import Any, TypeVar

_KT = TypeVar("_KT")
_VT = TypeVar("_VT")

unichr = chr

def camel2under(camel_string: str) -> str: ...
def under2camel(under_string: str) -> str: ...
def slugify(text: str, delim: str = "_", lower: bool = True, ascii: bool = False) -> str: ...
def split_punct_ws(text: str) -> str: ...
def unit_len(sized_iterable: Iterable[Any], unit_noun: str = "item") -> str: ...
def ordinalize(number: int | str, ext_only: bool = False) -> str: ...
def cardinalize(unit_noun: str, count: int) -> str: ...
def singularize(word: str) -> str: ...
def pluralize(word: str) -> str: ...
def find_hashtags(string: str) -> list[str]: ...
def a10n(string: str) -> str: ...
def strip_ansi(text: str) -> str: ...
def asciify(text: str, ignore: bool = False): ...
def is_ascii(text: str) -> bool: ...

class DeaccenterDict(dict[_KT, _VT]):
    def __missing__(self, key: _KT) -> _VT: ...
    def __getitem__(self, key: _KT) -> _VT: ...

def bytes2human(nbytes: int, ndigits: int = 0) -> str: ...

class HTMLTextExtractor(HTMLParser):
    strict: bool
    convert_charrefs: bool
    result: list[str]
    def __init__(self) -> None: ...
    def handle_data(self, d: str) -> None: ...
    def handle_charref(self, number: str) -> None: ...
    def handle_entityref(self, name: str) -> None: ...
    def get_text(self) -> str: ...

def html2text(html: str) -> str: ...
def gunzip_bytes(bytestring: bytes) -> bytes: ...
def gzip_bytes(bytestring: bytes, level: int = 6) -> int: ...
def iter_splitlines(text: str) -> Generator[str, None, None]: ...
def indent(text: str, margin: str, newline: str = "\n", key: Callable[..., bool] = ...) -> str: ...
def is_uuid(obj, version: int = 4) -> bool: ...
def escape_shell_args(args: list[str], sep: str = " ", style: str | None = None) -> str: ...
def args2sh(args: list[str], sep: str = " ") -> str: ...
def args2cmd(args: list[str], sep: str = " ") -> str: ...
def parse_int_list(range_string: str, delim: str = ",", range_delim: str = "-") -> list[int]: ...
def format_int_list(int_list: list[int], delim: str = ",", range_delim: str = "-", delim_space: bool = False) -> str: ...

class MultiReplace:
    group_map: dict[str, str]
    combined_pattern: str
    def __init__(self, sub_map: dict[str, str], **kwargs) -> None: ...
    def sub(self, text: str) -> str: ...

def multi_replace(text: str, sub_map: dict[str, str], **kwargs) -> str: ...
def unwrap_text(text: str, ending: str = "\n\n") -> str: ...

# Names in __all__ with no definition:
#   int_list_complement
#   int_list_to_int_tuples



from _typeshed import HasFileno, OptExcInfo, ReadOnlyBuffer
from _typeshed.wsgi import WSGIApplication
from collections.abc import Callable
from types import ModuleType
from typing import Any, Literal, Protocol, final, overload
from typing_extensions import Self, TypeAlias

import uwsgidecorators

_TrueOrNone: TypeAlias = Literal[True] | None

class _RPCCallable(Protocol):
    def __call__(self, *args: bytes) -> bytes | None: ...

# FIXME: Technically we know the exact layout of _AppsDict and _WorkerDict
#        but TypedDict does not support bytes keys, so for now we use type
#        aliases to a more generic dict
_WorkerDict: TypeAlias = dict[bytes, Any]

SPOOL_IGNORE: Literal[0]
SPOOL_OK: Literal[-2]
SPOOL_RETRY: Literal[-1]
applications: dict[str, WSGIApplication | str] | None
buffer_size: int
cores: int
has_threads: int
hostname: bytes
is_a_reload: bool
loop: bytes | None
magic_table: dict[bytes, bytes]
numproc: int
opt: dict[str, bytes | Literal[True] | list[bytes | Literal[True]]]
sockets: list[int]
started_on: int
unbit: _TrueOrNone
version: bytes
version_info: tuple[int, int, int, int, bytes]
spoolers: tuple[bytes, ...]
queue_size: int

decorators = uwsgidecorators
spooler = uwsgidecorators.manage_spool_request
post_fork_hook = uwsgidecorators.postfork_chain_hook

@final
class SymbolsImporter:
    def find_module(self, fullname: str, /) -> Self | None: ...
    def load_module(self, fullname: str, /) -> ModuleType | None: ...

@final
class SymbolsZipImporter:
    def __init__(self, name: str, /) -> None: ...
    def find_module(self, fullname: str, /) -> Self | None: ...
    def load_module(self, fullname: str, /) -> ModuleType | None: ...

@final
class ZipImporter:
    def __init__(self, name: str, /) -> None: ...
    def find_module(self, fullname: str, /) -> Self | None: ...
    def load_module(self, fullname: str, /) -> ModuleType | None: ...

def accepting(accepting: bool = True, /) -> None: ...
def add_cron(signum: int, minute: int, hour: int, day: int, month: int, weekday: int, /) -> Literal[True]: ...
def add_file_monitor(signum: int, filename: str, /) -> None: ...
def add_rb_timer(signum: int, seconds: int, iterations: int = 0, /) -> None: ...
def add_timer(signum: int, seconds: int, /) -> None: ...
def add_var(key: bytes | str, val: bytes | str, /) -> Literal[True]: ...
def alarm(alarm: str, msg: bytes | ReadOnlyBuffer | str, /) -> None: ...
def async_connect(socket_name: str, /) -> int: ...
def async_sleep(timeout: float, /) -> Literal[b""]: ...
def cache_clear(cache_name: str = ..., /) -> _TrueOrNone: ...
def cache_dec(key: str | bytes, decrement: int = 1, expires: int = 0, cache_name: str = ..., /) -> _TrueOrNone: ...
def cache_del(key: str | bytes, cache_name: str = ..., /) -> _TrueOrNone: ...
def cache_div(key: str | bytes, divisor: int = 2, expires: int = 0, cache_name: str = ..., /) -> _TrueOrNone: ...
def cache_exists(key: str | bytes, cache_name: str = ..., /) -> _TrueOrNone: ...
def cache_get(key: str | bytes, cache_name: str = ..., /) -> bytes | None: ...
def cache_inc(key: str | bytes, increment: int = 1, expires: int = 0, cache_name: str = ..., /) -> _TrueOrNone: ...
def cache_keys(cache_name: str = ..., /) -> list[bytes]: ...
def cache_mul(key: str | bytes, factor: int = 2, expires: int = 0, cache_name: str = ..., /) -> _TrueOrNone: ...
def cache_num(key: str | bytes, cache_name: str = ..., /) -> int: ...
def cache_set(
    key: str | bytes, value: str | bytes | ReadOnlyBuffer, expires: int = 0, cache_name: str = ..., /
) -> _TrueOrNone: ...
def cache_update(
    key: str | bytes, value: str | bytes | ReadOnlyBuffer, expires: int = 0, cache_name: str = ..., /
) -> _TrueOrNone: ...
def queue_get(index: int, /) -> bytes | None: ...
def queue_set(index: int, message: str | bytes | ReadOnlyBuffer, /) -> _TrueOrNone: ...
@overload
def queue_last(num: Literal[0] = 0, /) -> bytes | None: ...  # type: ignore[overload-overlap]
@overload
def queue_last(num: int, /) -> list[bytes | None]: ...
def queue_push(message: str | bytes | ReadOnlyBuffer, /) -> _TrueOrNone: ...
def queue_pull() -> bytes | None: ...
def queue_pop() -> bytes | None: ...
def queue_slot() -> int: ...
def queue_pull_slot() -> int: ...
def snmp_set_community(snmp_community: str, /) -> Literal[True]: ...
def snmp_set_counter32(oid_num: int, value: int, /) -> _TrueOrNone: ...
def snmp_set_counter64(oid_num: int, value: int, /) -> _TrueOrNone: ...
def snmp_set_gauge(oid_num: int, value: int, /) -> _TrueOrNone: ...
def snmp_incr_counter32(oid_num: int, increment: int, /) -> _TrueOrNone: ...
def snmp_incr_counter64(oid_num: int, increment: int, /) -> _TrueOrNone: ...
def snmp_incr_gauge(oid_num: int, increment: int, /) -> _TrueOrNone: ...
def snmp_decr_counter32(oid_num: int, decrement: int, /) -> _TrueOrNone: ...
def snmp_decr_counter64(oid_num: int, decrement: int, /) -> _TrueOrNone: ...
def snmp_decr_gauge(oid_num: int, decrement: int, /) -> _TrueOrNone: ...
@overload
def send_to_spooler(mesage_dict: dict[bytes, bytes], /) -> bytes | None: ...
@overload
def send_to_spooler(
    *, spooler: bytes = ..., priority: bytes = ..., at: bytes = ..., body: bytes = ..., **kwargs: bytes
) -> bytes | None: ...

spool = send_to_spooler

def set_spooler_frequency(frequency: int, /) -> Literal[True]: ...
def spooler_jobs() -> list[bytes]: ...
def spooler_pid() -> int: ...
def spooler_pids() -> list[int]: ...
def spooler_get_task(task_path: str, /) -> dict[bytes, bytes] | None: ...
def call(rpc_name: str, /, *args: bytes) -> bytes | None: ...
def chunked_read(timeout: int = 0, /) -> bytes: ...
def chunked_read_nb() -> bytes: ...
def cl() -> int: ...
def close(fd: int, /) -> None: ...
def connect(socket_name: str, /, timeout: int = 0) -> int: ...
def connection_fd() -> int: ...
def disconnect() -> None: ...
def embedded_data(name: str, /) -> bytes: ...
def extract(name: str, /) -> bytes | None: ...
def farm_get_msg() -> bytes | None: ...
def farm_msg(farm_name: str, message: str | bytes | ReadOnlyBuffer, /) -> None: ...
def get_logvar(key: str | bytes, /) -> bytes | None: ...
def green_schedule() -> Literal[True]: ...
def i_am_the_lord(legion_name: str, /) -> bool: ...
def i_am_the_spooler() -> _TrueOrNone: ...
def in_farm(farm_name: str = ..., /) -> _TrueOrNone: ...
def is_connected(fd: int, /) -> bool: ...
def is_locked(lock_num: int = 0, /) -> bool: ...
def listen_queue(id: int = 0, /) -> int: ...
def lock(lock_num: int = 0, /) -> None: ...
def log(logline: str, /) -> Literal[True]: ...
def log_this_request() -> None: ...
def logsize() -> int: ...
def lord_scroll(legion_name: str, /) -> bytes | None: ...
def masterpid() -> int: ...
def mem() -> tuple[int, int]: ...
def metric_dec(key: str, decrement: int = 1, /) -> _TrueOrNone: ...
def metric_div(key: str, divisor: int = 1, /) -> _TrueOrNone: ...
def metric_get(key: str, /) -> int: ...
def metric_inc(key: str, increment: int = 1, /) -> _TrueOrNone: ...
def metric_mul(key: str, factor: int = 1, /) -> _TrueOrNone: ...
def metric_set(key: str, value: int = 1, /) -> _TrueOrNone: ...
def metric_set_max(key: str, value: int = 1, /) -> _TrueOrNone: ...
def metric_set_min(key: str, value: int = 1, /) -> _TrueOrNone: ...
def micros() -> int: ...
def mule_get_msg(signals: bool = True, farms: bool = True, buffer_size: int = 65536, timeout: int = -1) -> bytes: ...
def mule_id() -> int: ...
@overload
def mule_msg(mesage: str | bytes | ReadOnlyBuffer, /) -> bool: ...
@overload
def mule_msg(mesage: str | bytes | ReadOnlyBuffer, mule_id: int, /) -> bool: ...
@overload
def mule_msg(mesage: str | bytes | ReadOnlyBuffer, farm_name: str, /) -> bool: ...
def offload(filename: str, len: int = 0, /) -> Literal[b""]: ...
def parsefile(filename: str, /) -> dict[bytes, bytes] | None: ...
def ready() -> _TrueOrNone: ...
def ready_fd() -> int: ...
def recv(fd: int, max_size: int = 4096, /) -> bytes | None: ...
@overload
def register_rpc(name: str, func: Callable[[], bytes | None], /) -> Literal[True]: ...
@overload
def register_rpc(name: str, func: Callable[[bytes], bytes | None], /, arg_count: Literal[1]) -> Literal[True]: ...
@overload
def register_rpc(name: str, func: Callable[[bytes, bytes], bytes | None], /, arg_count: Literal[2]) -> Literal[True]: ...
@overload
def register_rpc(name: str, func: _RPCCallable, /, arg_count: int) -> Literal[True]: ...
def register_signal(signum: int, who: str, handler: Callable[[int], Any], /) -> None: ...
def reload() -> _TrueOrNone: ...
def request_id() -> int: ...
def route(router_name: str, router_args: str, /) -> int: ...
def rpc(node: str | bytes, rpc_name: bytes, /, *rpc_args: bytes) -> bytes | None: ...
def rpc_list() -> tuple[bytes, ...]: ...
def scrolls(legion_name: str, /) -> list[bytes] | None: ...
@overload
def send(data: bytes, /) -> _TrueOrNone: ...
@overload
def send(fd: int, data: bytes, /) -> _TrueOrNone: ...
def sendfile(
    filename_or_fd: str | bytes | int | HasFileno, chunk: int = 0, pos: int = 0, /, filesize: int = 0
) -> _TrueOrNone: ...
def set_logvar(key: str | bytes, val: str | bytes, /) -> None: ...
def set_user_harakiri(seconds: int, /) -> None: ...
def set_warning_message(message: str, /) -> Literal[True]: ...
def setprocname(name: str, /) -> None: ...
def signal(signum: int = ..., node: str = ..., /) -> None: ...
def signal_received() -> int: ...
def signal_registered(signum: int, /) -> _TrueOrNone: ...
def signal_wait(signum: int = ..., /) -> Literal[b""]: ...
def start_response(
    status: str, headers: list[tuple[str, str]], exc_info: OptExcInfo | None = ..., /
) -> Callable[[bytes], None]: ...
def stop() -> _TrueOrNone: ...
def suspend() -> Literal[True]: ...
def total_requests() -> int: ...
def unlock(lock_num: int = 0, /) -> None: ...
def wait_fd_read(fd: int, timeout: int = 0, /) -> Literal[b""]: ...
def wait_fd_write(fd: int, timeout: int = 0, /) -> Literal[b""]: ...
def websocket_handshake(key: str | bytes = ..., origin: str | bytes = ..., proto: str | bytes = ..., /) -> None: ...
def websocket_recv() -> bytes: ...
def websocket_recv_nb() -> bytes: ...
def websocket_send(message: str | bytes | ReadOnlyBuffer) -> None: ...
def websocket_send_binary(message: str | bytes | ReadOnlyBuffer) -> None: ...
def worker_id() -> int: ...
def workers() -> tuple[_WorkerDict, ...] | None: ...
def sharedarea_read(id: int, position: int, length: int, /) -> bytes: ...
def sharedarea_write(id: int, position: int, value: str | bytes | ReadOnlyBuffer, /) -> None: ...
def sharedarea_readbyte(id: int, position: int, /) -> int: ...
def sharedarea_writebyte(id: int, position: int, value: int, /) -> None: ...
def sharedarea_read8(id: int, position: int, /) -> int: ...
def sharedarea_write8(id: int, position: int, value: int, /) -> None: ...
def sharedarea_readlong(id: int, position: int, /) -> int: ...
def sharedarea_writelong(id: int, position: int, value: int, /) -> None: ...
def sharedarea_read64(id: int, position: int, /) -> int: ...
def sharedarea_write64(id: int, position: int, value: int, /) -> None: ...
def sharedarea_read32(id: int, position: int, /) -> int: ...
def sharedarea_write32(id: int, position: int, value: int, /) -> None: ...
def sharedarea_read16(id: int, position: int, /) -> int: ...
def sharedarea_write16(id: int, position: int, value: int, /) -> None: ...
def sharedarea_inclong(id: int, position: int, increment: int = 1, /) -> None: ...
def sharedarea_inc64(id: int, position: int, increment: int = 1, /) -> None: ...
def sharedarea_inc32(id: int, position: int, increment: int = 1, /) -> None: ...
def sharedarea_dec64(id: int, position: int, decrement: int = 1, /) -> None: ...
def sharedarea_dec32(id: int, position: int, decrement: int = 1, /) -> None: ...
def sharedarea_rlock(id: int, /) -> None: ...
def sharedarea_wlock(id: int, /) -> None: ...
def sharedarea_unlock(id: int, /) -> None: ...
def sharedarea_object(id: int, /) -> bytearray: ...
def sharedarea_memoryview(id: int, /) -> memoryview: ...



from networkx.algorithms import *
from networkx.classes import *
from networkx.classes import filters as filters
from networkx.convert import *
from networkx.convert_matrix import *
from networkx.drawing import *
from networkx.exception import *
from networkx.generators import *
from networkx.lazy_imports import _lazy_import as _lazy_import
from networkx.linalg import *
from networkx.readwrite import *
from networkx.relabel import *
from networkx.utils.backends import _dispatch as _dispatch

from . import (
    algorithms as algorithms,
    classes as classes,
    convert as convert,
    convert_matrix as convert_matrix,
    drawing as drawing,
    generators as generators,
    linalg as linalg,
    readwrite as readwrite,
    relabel as relabel,
    utils as utils,
)



class FFIError(Exception):
    __module__: str

class CDefError(Exception):
    __module__: str

class VerificationError(Exception):
    __module__: str

class VerificationMissing(Exception):
    __module__: str

class PkgConfigError(Exception):
    __module__: str



from _typeshed import Incomplete
from typing import Any

def tag(key, value): ...

class WebsiteConfiguration:
    suffix: Any
    error_key: Any
    redirect_all_requests_to: Any
    routing_rules: Any
    def __init__(
        self,
        suffix: Incomplete | None = None,
        error_key: Incomplete | None = None,
        redirect_all_requests_to: Incomplete | None = None,
        routing_rules: Incomplete | None = None,
    ) -> None: ...
    def startElement(self, name, attrs, connection): ...
    def endElement(self, name, value, connection): ...
    def to_xml(self): ...

class _XMLKeyValue:
    translator: Any
    container: Any
    def __init__(self, translator, container: Incomplete | None = None) -> None: ...
    def startElement(self, name, attrs, connection): ...
    def endElement(self, name, value, connection): ...
    def to_xml(self): ...

class RedirectLocation(_XMLKeyValue):
    TRANSLATOR: Any
    hostname: Any
    protocol: Any
    def __init__(self, hostname: Incomplete | None = None, protocol: Incomplete | None = None) -> None: ...
    def to_xml(self): ...

class RoutingRules(list[RoutingRule]):
    def add_rule(self, rule: RoutingRule) -> RoutingRules: ...
    def startElement(self, name, attrs, connection): ...
    def endElement(self, name, value, connection): ...
    def to_xml(self): ...

class RoutingRule:
    condition: Any
    redirect: Any
    def __init__(self, condition: Incomplete | None = None, redirect: Incomplete | None = None) -> None: ...
    def startElement(self, name, attrs, connection): ...
    def endElement(self, name, value, connection): ...
    def to_xml(self): ...
    @classmethod
    def when(cls, key_prefix: Incomplete | None = None, http_error_code: Incomplete | None = None): ...
    def then_redirect(
        self,
        hostname: Incomplete | None = None,
        protocol: Incomplete | None = None,
        replace_key: Incomplete | None = None,
        replace_key_prefix: Incomplete | None = None,
        http_redirect_code: Incomplete | None = None,
    ): ...

class Condition(_XMLKeyValue):
    TRANSLATOR: Any
    key_prefix: Any
    http_error_code: Any
    def __init__(self, key_prefix: Incomplete | None = None, http_error_code: Incomplete | None = None) -> None: ...
    def to_xml(self): ...

class Redirect(_XMLKeyValue):
    TRANSLATOR: Any
    hostname: Any
    protocol: Any
    replace_key: Any
    replace_key_prefix: Any
    http_redirect_code: Any
    def __init__(
        self,
        hostname: Incomplete | None = None,
        protocol: Incomplete | None = None,
        replace_key: Incomplete | None = None,
        replace_key_prefix: Incomplete | None = None,
        http_redirect_code: Incomplete | None = None,
    ) -> None: ...
    def to_xml(self): ...



from collections.abc import Mapping, Set as AbstractSet
from datetime import datetime
from typing import Any, Literal, overload

from ..date import _DetectLanguagesFunction

@overload
def search_dates(
    text: str,
    languages: list[str] | tuple[str, ...] | AbstractSet[str] | None,
    settings: Mapping[Any, Any] | None,
    add_detected_language: Literal[True],
    detect_languages_function: _DetectLanguagesFunction | None = None,
) -> list[tuple[str, datetime, str]]: ...
@overload
def search_dates(
    text: str,
    languages: list[str] | tuple[str, ...] | AbstractSet[str] | None = None,
    settings: Mapping[Any, Any] | None = None,
    add_detected_language: Literal[False] = False,
    detect_languages_function: _DetectLanguagesFunction | None = None,
) -> list[tuple[str, datetime]]: ...



from _typeshed import Incomplete

from influxdb_client.service._base_service import _BaseService

class QueryService(_BaseService):
    def __init__(self, api_client: Incomplete | None = None) -> None: ...
    def get_query_suggestions(self, **kwargs): ...
    def get_query_suggestions_with_http_info(self, **kwargs): ...
    async def get_query_suggestions_async(self, **kwargs): ...
    def get_query_suggestions_name(self, name, **kwargs): ...
    def get_query_suggestions_name_with_http_info(self, name, **kwargs): ...
    async def get_query_suggestions_name_async(self, name, **kwargs): ...
    def post_query(self, **kwargs): ...
    def post_query_with_http_info(self, **kwargs): ...
    async def post_query_async(self, **kwargs): ...
    def post_query_analyze(self, **kwargs): ...
    def post_query_analyze_with_http_info(self, **kwargs): ...
    async def post_query_analyze_async(self, **kwargs): ...
    def post_query_ast(self, **kwargs): ...
    def post_query_ast_with_http_info(self, **kwargs): ...
    async def post_query_ast_async(self, **kwargs): ...



from _typeshed import Incomplete

from stripe.stripe_object import StripeObject as StripeObject

class ErrorObject(StripeObject):
    def refresh_from(
        self,
        values,
        api_key: Incomplete | None = None,
        partial: bool = False,
        stripe_version: Incomplete | None = None,
        stripe_account: Incomplete | None = None,
        last_response: Incomplete | None = None,
    ): ...

class OAuthErrorObject(StripeObject):
    def refresh_from(
        self,
        values,
        api_key: Incomplete | None = None,
        partial: bool = False,
        stripe_version: Incomplete | None = None,
        stripe_account: Incomplete | None = None,
        last_response: Incomplete | None = None,
    ): ...



from _typeshed import Incomplete
from decimal import Decimal
from typing import Final

from braintree.attribute_getter import AttributeGetter
from braintree.risk_data import RiskData
from braintree.three_d_secure_info import ThreeDSecureInfo

class CreditCardVerification(AttributeGetter):
    class Status:
        Failed: Final = "failed"
        GatewayRejected: Final = "gateway_rejected"
        ProcessorDeclined: Final = "processor_declined"
        Verified: Final = "verified"

    amount: Decimal | None
    currency_iso_code: Incomplete
    processor_response_code: Incomplete
    processor_response_text: Incomplete
    network_response_code: Incomplete
    network_response_text: Incomplete
    risk_data: RiskData | None
    three_d_secure_info: ThreeDSecureInfo | None
    def __init__(self, gateway, attributes) -> None: ...
    @staticmethod
    def find(verification_id): ...
    @staticmethod
    def search(*query): ...
    @staticmethod
    def create(params): ...
    @staticmethod
    def create_signature(): ...
    def __eq__(self, other): ...



from braintree.address import Address
from braintree.resource import Resource
from braintree.subscription import Subscription

class SamsungPayCard(Resource):
    billing_address: Address | None
    subscriptions: list[Subscription]
    def __init__(self, gateway, attributes) -> None: ...
    @property
    def expiration_date(self): ...
    @property
    def masked_number(self): ...



from google.cloud.ndb._datastore_api import EVENTUAL as EVENTUAL, EVENTUAL_CONSISTENCY as EVENTUAL_CONSISTENCY, STRONG as STRONG
from google.cloud.ndb._datastore_query import Cursor as Cursor, QueryIterator as QueryIterator
from google.cloud.ndb._transaction import (
    in_transaction as in_transaction,
    non_transactional as non_transactional,
    transaction as transaction,
    transaction_async as transaction_async,
    transactional as transactional,
    transactional_async as transactional_async,
    transactional_tasklet as transactional_tasklet,
)
from google.cloud.ndb.client import Client as Client
from google.cloud.ndb.context import (
    AutoBatcher as AutoBatcher,
    Context as Context,
    ContextOptions as ContextOptions,
    TransactionOptions as TransactionOptions,
    get_context as get_context,
    get_toplevel_context as get_toplevel_context,
)
from google.cloud.ndb.global_cache import GlobalCache as GlobalCache, MemcacheCache as MemcacheCache, RedisCache as RedisCache
from google.cloud.ndb.key import Key as Key
from google.cloud.ndb.model import (
    BadProjectionError as BadProjectionError,
    BlobKey as BlobKey,
    BlobKeyProperty as BlobKeyProperty,
    BlobProperty as BlobProperty,
    BooleanProperty as BooleanProperty,
    ComputedProperty as ComputedProperty,
    ComputedPropertyError as ComputedPropertyError,
    DateProperty as DateProperty,
    DateTimeProperty as DateTimeProperty,
    Expando as Expando,
    FloatProperty as FloatProperty,
    GenericProperty as GenericProperty,
    GeoPt as GeoPt,
    GeoPtProperty as GeoPtProperty,
    Index as Index,
    IndexProperty as IndexProperty,
    IndexState as IndexState,
    IntegerProperty as IntegerProperty,
    InvalidPropertyError as InvalidPropertyError,
    JsonProperty as JsonProperty,
    KeyProperty as KeyProperty,
    KindError as KindError,
    LocalStructuredProperty as LocalStructuredProperty,
    MetaModel as MetaModel,
    Model as Model,
    ModelAdapter as ModelAdapter,
    ModelAttribute as ModelAttribute,
    ModelKey as ModelKey,
    PickleProperty as PickleProperty,
    Property as Property,
    ReadonlyPropertyError as ReadonlyPropertyError,
    Rollback as Rollback,
    StringProperty as StringProperty,
    StructuredProperty as StructuredProperty,
    TextProperty as TextProperty,
    TimeProperty as TimeProperty,
    UnprojectedPropertyError as UnprojectedPropertyError,
    User as User,
    UserNotFoundError as UserNotFoundError,
    UserProperty as UserProperty,
    delete_multi as delete_multi,
    delete_multi_async as delete_multi_async,
    get_indexes as get_indexes,
    get_indexes_async as get_indexes_async,
    get_multi as get_multi,
    get_multi_async as get_multi_async,
    make_connection as make_connection,
    put_multi as put_multi,
    put_multi_async as put_multi_async,
)
from google.cloud.ndb.polymodel import PolyModel as PolyModel
from google.cloud.ndb.query import (
    AND as AND,
    OR as OR,
    ConjunctionNode as ConjunctionNode,
    DisjunctionNode as DisjunctionNode,
    FalseNode as FalseNode,
    FilterNode as FilterNode,
    Node as Node,
    Parameter as Parameter,
    ParameterizedFunction as ParameterizedFunction,
    ParameterizedThing as ParameterizedThing,
    ParameterNode as ParameterNode,
    PostFilterNode as PostFilterNode,
    Query as Query,
    QueryOptions as QueryOptions,
    RepeatedStructuredPropertyPredicate as RepeatedStructuredPropertyPredicate,
    gql as gql,
)
from google.cloud.ndb.tasklets import (
    Future as Future,
    QueueFuture as QueueFuture,
    ReducingFuture as ReducingFuture,
    Return as Return,
    SerialQueueFuture as SerialQueueFuture,
    add_flow_exception as add_flow_exception,
    make_context as make_context,
    make_default_context as make_default_context,
    set_context as set_context,
    sleep as sleep,
    synctasklet as synctasklet,
    tasklet as tasklet,
    toplevel as toplevel,
    wait_all as wait_all,
    wait_any as wait_any,
)
from google.cloud.ndb.version import __version__ as __version__

__all__ = [
    "__version__",
    "AutoBatcher",
    "Client",
    "Context",
    "ContextOptions",
    "EVENTUAL",
    "EVENTUAL_CONSISTENCY",
    "STRONG",
    "TransactionOptions",
    "Key",
    "BlobKey",
    "BlobKeyProperty",
    "BlobProperty",
    "BooleanProperty",
    "ComputedProperty",
    "ComputedPropertyError",
    "DateProperty",
    "DateTimeProperty",
    "delete_multi",
    "delete_multi_async",
    "Expando",
    "FloatProperty",
    "GenericProperty",
    "GeoPt",
    "GeoPtProperty",
    "get_indexes",
    "get_indexes_async",
    "get_multi",
    "get_multi_async",
    "GlobalCache",
    "in_transaction",
    "Index",
    "IndexProperty",
    "IndexState",
    "IntegerProperty",
    "InvalidPropertyError",
    "BadProjectionError",
    "JsonProperty",
    "KeyProperty",
    "KindError",
    "LocalStructuredProperty",
    "make_connection",
    "MemcacheCache",
    "MetaModel",
    "Model",
    "ModelAdapter",
    "ModelAttribute",
    "ModelKey",
    "non_transactional",
    "PickleProperty",
    "PolyModel",
    "Property",
    "put_multi",
    "put_multi_async",
    "ReadonlyPropertyError",
    "RedisCache",
    "Rollback",
    "StringProperty",
    "StructuredProperty",
    "TextProperty",
    "TimeProperty",
    "transaction",
    "transaction_async",
    "transactional",
    "transactional_async",
    "transactional_tasklet",
    "UnprojectedPropertyError",
    "User",
    "UserNotFoundError",
    "UserProperty",
    "ConjunctionNode",
    "AND",
    "Cursor",
    "DisjunctionNode",
    "OR",
    "FalseNode",
    "FilterNode",
    "gql",
    "Node",
    "Parameter",
    "ParameterizedFunction",
    "ParameterizedThing",
    "ParameterNode",
    "PostFilterNode",
    "Query",
    "QueryIterator",
    "QueryOptions",
    "RepeatedStructuredPropertyPredicate",
    "add_flow_exception",
    "Future",
    "get_context",
    "get_toplevel_context",
    "make_context",
    "make_default_context",
    "QueueFuture",
    "ReducingFuture",
    "Return",
    "SerialQueueFuture",
    "set_context",
    "sleep",
    "synctasklet",
    "tasklet",
    "toplevel",
    "wait_all",
    "wait_any",
]



from collections.abc import Collection
from datetime import datetime
from typing import Any, overload
from typing_extensions import TypeAlias

from webob.response import Response

_ETag: TypeAlias = _AnyETag | _NoETag | ETagMatcher

class _ETagProperty:
    @overload
    def __get__(self, obj: None, type: type | None = ..., /) -> property: ...
    @overload
    def __get__(self, obj: Any, type: type | None = ..., /) -> _ETag: ...
    @overload
    def __set__(self, obj: Any, value: str | None, /) -> None: ...
    @overload
    def __set__(self, obj: Any, value: _ETag, /) -> None: ...
    def __delete__(self, obj: Any, /) -> None: ...

def etag_property(key: str, default: _ETag, rfc_section: str, strong: bool = True) -> _ETagProperty: ...

class _AnyETag:
    def __bool__(self) -> bool: ...
    def __contains__(self, other: str) -> bool: ...

AnyETag: _AnyETag

class _NoETag:
    def __bool__(self) -> bool: ...
    def __contains__(self, other: str) -> bool: ...

NoETag: _NoETag

class ETagMatcher:
    etags: Collection[str]
    def __init__(self, etags: Collection[str]) -> None: ...
    def __contains__(self, other: str) -> bool: ...
    @classmethod
    def parse(cls, value: str, strong: bool = True) -> ETagMatcher | _AnyETag: ...

class IfRange:
    etag: _ETag
    def __init__(self, etag: _ETag) -> None: ...
    @classmethod
    def parse(cls, value: str) -> IfRange | IfRangeDate: ...
    def __contains__(self, resp: Response) -> bool: ...
    def __bool__(self) -> bool: ...

class IfRangeDate:
    date: datetime
    def __init__(self, date: datetime) -> None: ...
    def __contains__(self, resp: Response) -> bool: ...



from networkx.classes.digraph import DiGraph
from networkx.classes.graph import _Node
from networkx.classes.multigraph import MultiGraph
from networkx.classes.reportviews import InMultiDegreeView, MultiDegreeView, OutMultiDegreeView

class MultiDiGraph(MultiGraph[_Node], DiGraph[_Node]):
    degree: MultiDegreeView[_Node]
    in_degree: InMultiDegreeView[_Node]
    out_degree: OutMultiDegreeView[_Node]
    def to_undirected(self, reciprocal: bool = False, as_view: bool = False) -> MultiGraph[_Node]: ...  # type: ignore
    def reverse(self, copy: bool = True) -> MultiDiGraph[_Node]: ...
    def copy(self, as_view: bool = False) -> MultiDiGraph[_Node]: ...



from _typeshed import Incomplete
from typing import ClassVar, Final, Literal

from ._imaging import _PixelAccessor
from .ImageFile import ImageFile

enable_jpeg2k: Incomplete
MAGIC: Final = b"icns"
HEADERSIZE: Final = 8

def nextheader(fobj): ...
def read_32t(fobj, start_length, size): ...
def read_32(fobj, start_length, size): ...
def read_mk(fobj, start_length, size): ...
def read_png_or_jpeg2000(fobj, start_length, size): ...

class IcnsFile:
    SIZES: Incomplete
    dct: Incomplete
    fobj: Incomplete
    def __init__(self, fobj) -> None: ...
    def itersizes(self): ...
    def bestsize(self): ...
    def dataforsize(self, size): ...
    def getimage(self, size: Incomplete | None = None): ...

class IcnsImageFile(ImageFile):
    format: ClassVar[Literal["ICNS"]]
    format_description: ClassVar[str]
    @property
    def size(self): ...
    @size.setter
    def size(self, value) -> None: ...
    best_size: Incomplete
    im: Incomplete
    def load(self) -> _PixelAccessor: ...



from typing import Any

log: Any

class Throwable:
    id: Any
    message: Any
    type: Any
    remote: Any
    stack: Any
    def __init__(self, exception, stack, remote: bool = False) -> None: ...
    def to_dict(self): ...



from builtins import type as _type  # type is being shadowed in Field
from collections.abc import Callable, Iterable, Sequence
from typing import Any, Generic, Protocol, TypeVar, overload
from typing_extensions import Self, TypeAlias

from markupsafe import Markup
from wtforms.form import BaseForm
from wtforms.meta import DefaultMeta, _MultiDictLikeWithGetlist, _SupportsGettextAndNgettext

_FormT = TypeVar("_FormT", bound=BaseForm)
_FieldT = TypeVar("_FieldT", bound=Field)
_FormT_contra = TypeVar("_FormT_contra", bound=BaseForm, contravariant=True)
_FieldT_contra = TypeVar("_FieldT_contra", bound=Field, contravariant=True)
# It would be nice to annotate this as invariant, i.e. input type and output type
# needs to be the same, but it will probably be too annoying to use, for now we
# trust, that people won't use it to change the type of data in a field...
_Filter: TypeAlias = Callable[[Any], Any]

class _Validator(Protocol[_FormT_contra, _FieldT_contra]):
    def __call__(self, form: _FormT_contra, field: _FieldT_contra, /) -> object: ...

class _Widget(Protocol[_FieldT_contra]):
    def __call__(self, field: _FieldT_contra, **kwargs: Any) -> Markup: ...

class Field:
    errors: Sequence[str]
    process_errors: Sequence[str]
    raw_data: list[Any] | None
    object_data: Any
    data: Any
    validators: Sequence[_Validator[Any, Self]]
    # even though this could be None on the base class, this should
    # never actually be None in a real field
    widget: _Widget[Self]
    do_not_call_in_templates: bool
    meta: DefaultMeta
    default: Any | None
    description: str
    render_kw: dict[str, Any]
    filters: Sequence[_Filter]
    flags: Flags
    name: str
    short_name: str
    id: str
    type: str
    label: Label
    # technically this can return UnboundField, but that is not allowed
    # by type checkers, so we use a descriptor hack to get around this
    # limitation instead
    def __new__(cls, *args: Any, **kwargs: Any) -> Self: ...
    def __init__(
        self,
        label: str | None = None,
        # for tuple we can be a bit more type safe and only accept validators
        # that would work on this or a less specific field, but in general it
        # would be too annoying to restrict to Sequence[_Validator], since mypy
        # will infer a list of mixed validators as list[object], since that is
        # the common base class between all validators
        validators: tuple[_Validator[_FormT, Self], ...] | list[Any] | None = None,
        filters: Sequence[_Filter] = (),
        description: str = "",
        id: str | None = None,
        default: object | None = None,
        widget: _Widget[Self] | None = None,
        render_kw: dict[str, Any] | None = None,
        name: str | None = None,
        _form: BaseForm | None = None,
        _prefix: str = "",
        _translations: _SupportsGettextAndNgettext | None = None,
        _meta: DefaultMeta | None = None,
    ) -> None: ...
    def __html__(self) -> str: ...
    def __call__(self, **kwargs: object) -> Markup: ...
    @classmethod
    def check_validators(cls, validators: Iterable[_Validator[_FormT, Self]] | None) -> None: ...
    def gettext(self, string: str) -> str: ...
    def ngettext(self, singular: str, plural: str, n: int) -> str: ...
    def validate(self, form: BaseForm, extra_validators: tuple[_Validator[_FormT, Self], ...] | list[Any] = ()) -> bool: ...
    def pre_validate(self, form: BaseForm) -> None: ...
    def post_validate(self, form: BaseForm, validation_stopped: bool) -> None: ...
    def process(
        self, formdata: _MultiDictLikeWithGetlist | None, data: Any = ..., extra_filters: Sequence[_Filter] | None = None
    ) -> None: ...
    def process_data(self, value: Any) -> None: ...
    def process_formdata(self, valuelist: list[Any]) -> None: ...
    def populate_obj(self, obj: object, name: str) -> None: ...

    # this is a workaround for what is essentially illegal in static type checking
    # Field.__new__ would return an UnboundField, unless the _form parameter is
    # specified. We can't really work around it by making UnboundField a subclass
    # of Field, since all subclasses of Field still need to return an UnboundField
    # and we can't expect third parties to add a __new__ method to every field
    # they define...
    # This workaround only works for Form, not BaseForm, but we take what we can get
    # BaseForm shouldn't really be used anyways
    @overload
    def __get__(self, obj: None, owner: _type[object] | None = None) -> UnboundField[Self]: ...
    @overload
    def __get__(self, obj: object, owner: _type[object] | None = None) -> Self: ...

class UnboundField(Generic[_FieldT]):
    creation_counter: int
    field_class: type[_FieldT]
    name: str | None
    args: tuple[Any, ...]
    kwargs: dict[str, Any]
    def __init__(self, field_class: type[_FieldT], *args: object, name: str | None = None, **kwargs: object) -> None: ...
    def bind(
        self,
        form: BaseForm,
        name: str,
        prefix: str = "",
        translations: _SupportsGettextAndNgettext | None = None,
        **kwargs: object,
    ) -> _FieldT: ...

class Flags:
    # the API for this is a bit loosey goosey, the intention probably
    # was that the values should always be boolean, but __contains__
    # just returns the same thing as __getattr__ and in the widgets
    # there are fields that could accept numeric values from Flags
    def __getattr__(self, name: str) -> Any | None: ...
    def __setattr__(self, name: str, value: object) -> None: ...
    def __delattr__(self, name: str) -> None: ...
    def __contains__(self, name: str) -> Any | None: ...

class Label:
    field_id: str
    text: str
    def __init__(self, field_id: str, text: str) -> None: ...
    def __html__(self) -> str: ...
    def __call__(self, text: str | None = None, **kwargs: Any) -> Markup: ...



from _typeshed import Incomplete
from collections.abc import Generator
from itertools import zip_longest as zip_longest

text_type = str
string_type = str

def with_str_method(cls): ...
def with_repr_method(cls): ...
def get_methods(cls) -> Generator[Incomplete, None, None]: ...



from _typeshed import Incomplete
from typing import ClassVar

from ..core import OrthodoxCalendar

class Ukraine(OrthodoxCalendar):
    shift_sunday_holidays: ClassVar[bool]
    shift_new_years_day: ClassVar[bool]
    FIXED_HOLIDAYS: Incomplete
    include_labour_day: ClassVar[bool]
    labour_day_label: ClassVar[str]
    include_christmas: ClassVar[bool]
    include_good_friday: ClassVar[bool]
    include_easter_sunday: ClassVar[bool]
    include_easter_monday: ClassVar[bool]
    include_whit_monday: ClassVar[bool]
    def get_variable_days(self, year): ...



from _typeshed import Incomplete

from influxdb_client.service._base_service import _BaseService

class DashboardsService(_BaseService):
    def __init__(self, api_client: Incomplete | None = None) -> None: ...
    def delete_dashboards_id(self, dashboard_id, **kwargs): ...
    def delete_dashboards_id_with_http_info(self, dashboard_id, **kwargs): ...
    async def delete_dashboards_id_async(self, dashboard_id, **kwargs): ...
    def delete_dashboards_id_cells_id(self, dashboard_id, cell_id, **kwargs): ...
    def delete_dashboards_id_cells_id_with_http_info(self, dashboard_id, cell_id, **kwargs): ...
    async def delete_dashboards_id_cells_id_async(self, dashboard_id, cell_id, **kwargs): ...
    def delete_dashboards_id_labels_id(self, dashboard_id, label_id, **kwargs): ...
    def delete_dashboards_id_labels_id_with_http_info(self, dashboard_id, label_id, **kwargs): ...
    async def delete_dashboards_id_labels_id_async(self, dashboard_id, label_id, **kwargs): ...
    def delete_dashboards_id_members_id(self, user_id, dashboard_id, **kwargs): ...
    def delete_dashboards_id_members_id_with_http_info(self, user_id, dashboard_id, **kwargs): ...
    async def delete_dashboards_id_members_id_async(self, user_id, dashboard_id, **kwargs): ...
    def delete_dashboards_id_owners_id(self, user_id, dashboard_id, **kwargs): ...
    def delete_dashboards_id_owners_id_with_http_info(self, user_id, dashboard_id, **kwargs): ...
    async def delete_dashboards_id_owners_id_async(self, user_id, dashboard_id, **kwargs): ...
    def get_dashboards(self, **kwargs): ...
    def get_dashboards_with_http_info(self, **kwargs): ...
    async def get_dashboards_async(self, **kwargs): ...
    def get_dashboards_id(self, dashboard_id, **kwargs): ...
    def get_dashboards_id_with_http_info(self, dashboard_id, **kwargs): ...
    async def get_dashboards_id_async(self, dashboard_id, **kwargs): ...
    def get_dashboards_id_cells_id_view(self, dashboard_id, cell_id, **kwargs): ...
    def get_dashboards_id_cells_id_view_with_http_info(self, dashboard_id, cell_id, **kwargs): ...
    async def get_dashboards_id_cells_id_view_async(self, dashboard_id, cell_id, **kwargs): ...
    def get_dashboards_id_labels(self, dashboard_id, **kwargs): ...
    def get_dashboards_id_labels_with_http_info(self, dashboard_id, **kwargs): ...
    async def get_dashboards_id_labels_async(self, dashboard_id, **kwargs): ...
    def get_dashboards_id_members(self, dashboard_id, **kwargs): ...
    def get_dashboards_id_members_with_http_info(self, dashboard_id, **kwargs): ...
    async def get_dashboards_id_members_async(self, dashboard_id, **kwargs): ...
    def get_dashboards_id_owners(self, dashboard_id, **kwargs): ...
    def get_dashboards_id_owners_with_http_info(self, dashboard_id, **kwargs): ...
    async def get_dashboards_id_owners_async(self, dashboard_id, **kwargs): ...
    def patch_dashboards_id(self, dashboard_id, **kwargs): ...
    def patch_dashboards_id_with_http_info(self, dashboard_id, **kwargs): ...
    async def patch_dashboards_id_async(self, dashboard_id, **kwargs): ...
    def patch_dashboards_id_cells_id(self, dashboard_id, cell_id, cell_update, **kwargs): ...
    def patch_dashboards_id_cells_id_with_http_info(self, dashboard_id, cell_id, cell_update, **kwargs): ...
    async def patch_dashboards_id_cells_id_async(self, dashboard_id, cell_id, cell_update, **kwargs): ...
    def patch_dashboards_id_cells_id_view(self, dashboard_id, cell_id, view, **kwargs): ...
    def patch_dashboards_id_cells_id_view_with_http_info(self, dashboard_id, cell_id, view, **kwargs): ...
    async def patch_dashboards_id_cells_id_view_async(self, dashboard_id, cell_id, view, **kwargs): ...
    def post_dashboards(self, create_dashboard_request, **kwargs): ...
    def post_dashboards_with_http_info(self, create_dashboard_request, **kwargs): ...
    async def post_dashboards_async(self, create_dashboard_request, **kwargs): ...
    def post_dashboards_id_cells(self, dashboard_id, create_cell, **kwargs): ...
    def post_dashboards_id_cells_with_http_info(self, dashboard_id, create_cell, **kwargs): ...
    async def post_dashboards_id_cells_async(self, dashboard_id, create_cell, **kwargs): ...
    def post_dashboards_id_labels(self, dashboard_id, label_mapping, **kwargs): ...
    def post_dashboards_id_labels_with_http_info(self, dashboard_id, label_mapping, **kwargs): ...
    async def post_dashboards_id_labels_async(self, dashboard_id, label_mapping, **kwargs): ...
    def post_dashboards_id_members(self, dashboard_id, add_resource_member_request_body, **kwargs): ...
    def post_dashboards_id_members_with_http_info(self, dashboard_id, add_resource_member_request_body, **kwargs): ...
    async def post_dashboards_id_members_async(self, dashboard_id, add_resource_member_request_body, **kwargs): ...
    def post_dashboards_id_owners(self, dashboard_id, add_resource_member_request_body, **kwargs): ...
    def post_dashboards_id_owners_with_http_info(self, dashboard_id, add_resource_member_request_body, **kwargs): ...
    async def post_dashboards_id_owners_async(self, dashboard_id, add_resource_member_request_body, **kwargs): ...
    def put_dashboards_id_cells(self, dashboard_id, cell, **kwargs): ...
    def put_dashboards_id_cells_with_http_info(self, dashboard_id, cell, **kwargs): ...
    async def put_dashboards_id_cells_async(self, dashboard_id, cell, **kwargs): ...



from decimal import Decimal

from braintree.resource import Resource

class SubscriptionStatusEvent(Resource):
    balance: Decimal
    price: Decimal
    def __init__(self, gateway, attributes) -> None: ...



from _typeshed import Incomplete

class CredentialsParser:
    client_id: Incomplete
    client_secret: Incomplete
    access_token: Incomplete
    def __init__(
        self, client_id: Incomplete | None = None, client_secret: Incomplete | None = None, access_token: Incomplete | None = None
    ) -> None: ...
    environment: Incomplete
    def parse_client_credentials(self) -> None: ...
    merchant_id: Incomplete
    def parse_access_token(self) -> None: ...
    def get_environment(self, credential): ...
    def get_merchant_id(self, credential): ...



from _typeshed import Incomplete
from collections.abc import Generator

from networkx.utils.backends import _dispatch

@_dispatch
def node_attribute_xy(G, attribute, nodes: Incomplete | None = None) -> Generator[Incomplete, None, None]: ...
@_dispatch
def node_degree_xy(
    G, x: str = "out", y: str = "in", weight: Incomplete | None = None, nodes: Incomplete | None = None
) -> Generator[Incomplete, None, None]: ...



import sys
from _typeshed import Incomplete
from ctypes import Structure, Union, _CField, _NamedFuncPointer, _Pointer, c_int64, c_ulong, c_void_p
from ctypes.wintypes import DWORD
from typing_extensions import TypeAlias

if sys.platform == "win32":
    def is_64bit() -> bool: ...

    ULONG_PTR: type[c_int64 | c_ulong]

    class _SECURITY_ATTRIBUTES(Structure):
        nLength: _CField[Incomplete, Incomplete, Incomplete]
        lpSecurityDescriptor: _CField[Incomplete, Incomplete, Incomplete]
        bInheritHandle: _CField[Incomplete, Incomplete, Incomplete]

    LPSECURITY_ATTRIBUTES: type[_Pointer[_SECURITY_ATTRIBUTES]]
    CreateEvent: _NamedFuncPointer
    CreateFile: _NamedFuncPointer
    # The following are included in __all__ but their existence is not guaranteed as
    # they are defined in a try/except block. Their aliases above are always defined.
    CreateEventW: _NamedFuncPointer
    CreateFileW: _NamedFuncPointer

    class _OVERLAPPED(Structure):
        Internal: _CField[Incomplete, Incomplete, Incomplete]
        InternalHigh: _CField[Incomplete, Incomplete, Incomplete]
        Offset: _CField[Incomplete, Incomplete, Incomplete]
        OffsetHigh: _CField[Incomplete, Incomplete, Incomplete]
        Pointer: _CField[Incomplete, Incomplete, Incomplete]
        hEvent: _CField[Incomplete, Incomplete, Incomplete]

    OVERLAPPED: TypeAlias = _OVERLAPPED

    class _COMSTAT(Structure):
        fCtsHold: _CField[Incomplete, Incomplete, Incomplete]
        fDsrHold: _CField[Incomplete, Incomplete, Incomplete]
        fRlsdHold: _CField[Incomplete, Incomplete, Incomplete]
        fXoffHold: _CField[Incomplete, Incomplete, Incomplete]
        fXoffSent: _CField[Incomplete, Incomplete, Incomplete]
        fEof: _CField[Incomplete, Incomplete, Incomplete]
        fTxim: _CField[Incomplete, Incomplete, Incomplete]
        fReserved: _CField[Incomplete, Incomplete, Incomplete]
        cbInQue: _CField[Incomplete, Incomplete, Incomplete]
        cbOutQue: _CField[Incomplete, Incomplete, Incomplete]

    COMSTAT: TypeAlias = _COMSTAT

    class _DCB(Structure):
        DCBlength: _CField[Incomplete, Incomplete, Incomplete]
        BaudRate: _CField[Incomplete, Incomplete, Incomplete]
        fBinary: _CField[Incomplete, Incomplete, Incomplete]
        fParity: _CField[Incomplete, Incomplete, Incomplete]
        fOutxCtsFlow: _CField[Incomplete, Incomplete, Incomplete]
        fOutxDsrFlow: _CField[Incomplete, Incomplete, Incomplete]
        fDtrControl: _CField[Incomplete, Incomplete, Incomplete]
        fDsrSensitivity: _CField[Incomplete, Incomplete, Incomplete]
        fTXContinueOnXoff: _CField[Incomplete, Incomplete, Incomplete]
        fOutX: _CField[Incomplete, Incomplete, Incomplete]
        fInX: _CField[Incomplete, Incomplete, Incomplete]
        fErrorChar: _CField[Incomplete, Incomplete, Incomplete]
        fNull: _CField[Incomplete, Incomplete, Incomplete]
        fRtsControl: _CField[Incomplete, Incomplete, Incomplete]
        fAbortOnError: _CField[Incomplete, Incomplete, Incomplete]
        fDummy2: _CField[Incomplete, Incomplete, Incomplete]
        wReserved: _CField[Incomplete, Incomplete, Incomplete]
        XonLim: _CField[Incomplete, Incomplete, Incomplete]
        XoffLim: _CField[Incomplete, Incomplete, Incomplete]
        ByteSize: _CField[Incomplete, Incomplete, Incomplete]
        Parity: _CField[Incomplete, Incomplete, Incomplete]
        StopBits: _CField[Incomplete, Incomplete, Incomplete]
        XonChar: _CField[Incomplete, Incomplete, Incomplete]
        XoffChar: _CField[Incomplete, Incomplete, Incomplete]
        ErrorChar: _CField[Incomplete, Incomplete, Incomplete]
        EofChar: _CField[Incomplete, Incomplete, Incomplete]
        EvtChar: _CField[Incomplete, Incomplete, Incomplete]
        wReserved1: _CField[Incomplete, Incomplete, Incomplete]

    DCB: TypeAlias = _DCB

    class _COMMTIMEOUTS(Structure):
        ReadIntervalTimeout: _CField[Incomplete, Incomplete, Incomplete]
        ReadTotalTimeoutMultiplier: _CField[Incomplete, Incomplete, Incomplete]
        ReadTotalTimeoutConstant: _CField[Incomplete, Incomplete, Incomplete]
        WriteTotalTimeoutMultiplier: _CField[Incomplete, Incomplete, Incomplete]
        WriteTotalTimeoutConstant: _CField[Incomplete, Incomplete, Incomplete]

    COMMTIMEOUTS: TypeAlias = _COMMTIMEOUTS

    GetLastError: _NamedFuncPointer
    LPOVERLAPPED: type[_Pointer[_OVERLAPPED]]
    LPDWORD: type[_Pointer[DWORD]]
    GetOverlappedResult: _NamedFuncPointer
    ResetEvent: _NamedFuncPointer
    LPCVOID = c_void_p
    WriteFile: _NamedFuncPointer
    LPVOID = c_void_p
    ReadFile: _NamedFuncPointer
    CloseHandle: _NamedFuncPointer
    ClearCommBreak: _NamedFuncPointer
    LPCOMSTAT: type[_Pointer[_COMSTAT]]
    ClearCommError: _NamedFuncPointer
    SetupComm: _NamedFuncPointer
    EscapeCommFunction: _NamedFuncPointer
    GetCommModemStatus: _NamedFuncPointer
    LPDCB: type[_Pointer[_DCB]]
    GetCommState: _NamedFuncPointer
    LPCOMMTIMEOUTS: type[_Pointer[_COMMTIMEOUTS]]
    GetCommTimeouts: _NamedFuncPointer
    PurgeComm: _NamedFuncPointer
    SetCommBreak: _NamedFuncPointer
    SetCommMask: _NamedFuncPointer
    SetCommState: _NamedFuncPointer
    SetCommTimeouts: _NamedFuncPointer
    WaitForSingleObject: _NamedFuncPointer
    WaitCommEvent: _NamedFuncPointer
    CancelIoEx: _NamedFuncPointer

    ONESTOPBIT: int
    TWOSTOPBITS: int
    NOPARITY: int
    ODDPARITY: int
    EVENPARITY: int
    RTS_CONTROL_HANDSHAKE: int
    RTS_CONTROL_ENABLE: int
    DTR_CONTROL_HANDSHAKE: int
    DTR_CONTROL_ENABLE: int
    MS_DSR_ON: int
    EV_RING: int
    EV_PERR: int
    EV_ERR: int
    SETXOFF: int
    EV_RXCHAR: int
    GENERIC_WRITE: int
    PURGE_TXCLEAR: int
    FILE_FLAG_OVERLAPPED: int
    EV_DSR: int
    MAXDWORD: int
    EV_RLSD: int
    ERROR_IO_PENDING: int
    MS_CTS_ON: int
    EV_EVENT1: int
    EV_RX80FULL: int
    PURGE_RXABORT: int
    FILE_ATTRIBUTE_NORMAL: int
    PURGE_TXABORT: int
    SETXON: int
    OPEN_EXISTING: int
    MS_RING_ON: int
    EV_TXEMPTY: int
    EV_RXFLAG: int
    MS_RLSD_ON: int
    GENERIC_READ: int
    EV_EVENT2: int
    EV_CTS: int
    EV_BREAK: int
    PURGE_RXCLEAR: int

    class N11_OVERLAPPED4DOLLAR_48E(Union):
        Offset: _CField[Incomplete, Incomplete, Incomplete]
        OffsetHigh: _CField[Incomplete, Incomplete, Incomplete]
        Pointer: _CField[Incomplete, Incomplete, Incomplete]

    class N11_OVERLAPPED4DOLLAR_484DOLLAR_49E(Structure):
        Offset: _CField[Incomplete, Incomplete, Incomplete]
        OffsetHigh: _CField[Incomplete, Incomplete, Incomplete]

    PVOID: TypeAlias = c_void_p



from _typeshed import SupportsItems
from collections.abc import Callable
from typing import Any

from pynput import _util

from ._base import Controller as Controller, Key as Key, KeyCode as KeyCode, Listener as Listener

class Events(_util.Events[Any, Listener]):
    class Press(_util.Events.Event):
        key: Key | KeyCode | None
        def __init__(self, key: Key | KeyCode | None) -> None: ...

    class Release(_util.Events.Event):
        key: Key | KeyCode | None
        def __init__(self, key: Key | KeyCode | None) -> None: ...

    def __init__(self) -> None: ...
    def __next__(self) -> Press | Release: ...
    def get(self, timeout: float | None = None) -> Press | Release | None: ...

class HotKey:
    def __init__(self, keys: list[KeyCode], on_activate: Callable[[], object]) -> None: ...
    @staticmethod
    def parse(keys: str) -> list[KeyCode]: ...
    def press(self, key: Key | KeyCode) -> None: ...
    def release(self, key: Key | KeyCode) -> None: ...

class GlobalHotKeys(Listener):
    def __init__(self, hotkeys: SupportsItems[str, Callable[[], None]], *args: Any, **kwargs: Any) -> None: ...



from _typeshed import Incomplete
from logging import Logger

from oauthlib.oauth1 import Client
from requests.auth import AuthBase

CONTENT_TYPE_FORM_URLENCODED: str
CONTENT_TYPE_MULTI_PART: str
log: Logger

class OAuth1(AuthBase):
    client_class: type[Client]
    client: Client
    force_include_body: bool
    def __init__(
        self,
        client_key,
        client_secret: Incomplete | None = None,
        resource_owner_key: Incomplete | None = None,
        resource_owner_secret: Incomplete | None = None,
        callback_uri: Incomplete | None = None,
        signature_method="HMAC-SHA1",
        signature_type="AUTH_HEADER",
        rsa_key: Incomplete | None = None,
        verifier: Incomplete | None = None,
        decoding: str = "utf-8",
        client_class: type[Client] | None = None,
        force_include_body: bool = False,
        *,
        encoding: str = "utf-8",
        nonce: Incomplete | None = None,
        timestamp: Incomplete | None = None,
    ) -> None: ...



from networkx.exception import NetworkXError
from networkx.utils.backends import _dispatch

__all__ = ["modularity", "partition_quality"]

class NotAPartition(NetworkXError):
    def __init__(self, G, collection) -> None: ...

@_dispatch
def modularity(G, communities, weight: str = "weight", resolution: float = 1): ...
@_dispatch
def partition_quality(G, partition): ...



from _typeshed import Incomplete
from typing import ClassVar

from ..core import WesternCalendar

class SaoTomeAndPrincipe(WesternCalendar):
    FIXED_HOLIDAYS: Incomplete
    include_labour_day: ClassVar[bool]
    include_all_saints: ClassVar[bool]



from _typeshed import Incomplete
from typing import IO
from typing_extensions import TypeAlias

__all__ = ["get_zonefile_instance", "gettz", "gettz_db_metadata"]

_MetadataType: TypeAlias = dict[str, Incomplete]

class ZoneInfoFile:
    zones: dict[Incomplete, Incomplete]
    metadata: _MetadataType | None
    def __init__(self, zonefile_stream: IO[bytes] | None = None) -> None: ...
    def get(self, name, default: Incomplete | None = None): ...

def get_zonefile_instance(new_instance: bool = False) -> ZoneInfoFile: ...
def gettz(name): ...
def gettz_db_metadata() -> _MetadataType: ...



from collections.abc import Callable, Iterable
from gettext import GNUTranslations
from typing import Protocol, TypeVar, overload

_T = TypeVar("_T")

class _SupportsUgettextAndUngettext(Protocol):
    def ugettext(self, string: str, /) -> str: ...
    def ungettext(self, singular: str, plural: str, n: int, /) -> str: ...

def messages_path() -> str: ...
def get_builtin_gnu_translations(languages: Iterable[str] | None = None) -> GNUTranslations: ...
@overload
def get_translations(
    languages: Iterable[str] | None = None, getter: Callable[[Iterable[str]], GNUTranslations] = ...
) -> GNUTranslations: ...
@overload
def get_translations(languages: Iterable[str] | None = None, *, getter: Callable[[Iterable[str]], _T]) -> _T: ...
@overload
def get_translations(languages: Iterable[str] | None, getter: Callable[[Iterable[str]], _T]) -> _T: ...

class DefaultTranslations:
    translations: _SupportsUgettextAndUngettext
    def __init__(self, translations: _SupportsUgettextAndUngettext) -> None: ...
    def gettext(self, string: str) -> str: ...
    def ngettext(self, singular: str, plural: str, n: int) -> str: ...

class DummyTranslations:
    def gettext(self, string: str) -> str: ...
    def ngettext(self, singular: str, plural: str, n: int) -> str: ...



from _typeshed import Incomplete

from .base import GrantTypeBase

log: Incomplete

class RefreshTokenGrant(GrantTypeBase):
    proxy_target: Incomplete
    def __init__(self, request_validator: Incomplete | None = None, **kwargs) -> None: ...
    def add_id_token(self, token, token_handler, request): ...



from _typeshed import Incomplete

from antlr4.Token import Token as Token

class RuleTagToken(Token):
    source: Incomplete
    type: Incomplete
    channel: Incomplete
    start: int
    stop: int
    tokenIndex: int
    line: int
    column: int
    label: Incomplete
    ruleName: Incomplete
    def __init__(self, ruleName: str, bypassTokenType: int, label: str | None = None) -> None: ...
    def getText(self): ...



import abc
from _typeshed import Incomplete

from qrcode.image.base import BaseImage

class QRModuleDrawer(abc.ABC, metaclass=abc.ABCMeta):
    needs_neighbors: bool
    def __init__(self, **kwargs) -> None: ...
    img: Incomplete
    def initialize(self, img: BaseImage) -> None: ...
    @abc.abstractmethod
    def drawrect(self, box, is_active) -> None: ...



from collections.abc import Iterator

from ._pygit2 import Branch, Commit, Oid
from .enums import BranchType
from .repository import BaseRepository

class Branches:
    local: Branches
    remote: Branches
    def __init__(self, repository: BaseRepository, flag: BranchType = ..., commit: Commit | Oid | None = None) -> None: ...
    def __getitem__(self, name: str) -> Branch: ...
    def get(self, key: str) -> Branch | None: ...
    def __iter__(self) -> Iterator[str]: ...
    def create(self, name: str, commit: Commit, force: bool = False) -> Branch: ...
    def delete(self, name: str) -> None: ...
    def with_commit(self, commit: Commit | Oid | None) -> Branches: ...
    def __contains__(self, name: str) -> bool: ...



from _typeshed import Incomplete

from exifread.tags.exif import EXIF_TAGS as EXIF_TAGS
from exifread.tags.makernote import (
    apple as apple,
    canon as canon,
    casio as casio,
    fujifilm as fujifilm,
    nikon as nikon,
    olympus as olympus,
)

DEFAULT_STOP_TAG: str
FIELD_TYPES: Incomplete
IGNORE_TAGS: Incomplete



from _typeshed import Incomplete

class TemplateExportByName:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self, stack_id: Incomplete | None = None, org_ids: Incomplete | None = None, resources: Incomplete | None = None
    ) -> None: ...
    @property
    def stack_id(self): ...
    @stack_id.setter
    def stack_id(self, stack_id) -> None: ...
    @property
    def org_ids(self): ...
    @org_ids.setter
    def org_ids(self, org_ids) -> None: ...
    @property
    def resources(self): ...
    @resources.setter
    def resources(self, resources) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import ReadableBuffer
from typing import IO

from paramiko.message import Message
from paramiko.pkey import PKey

class Ed25519Key(PKey):
    public_blob: None
    def __init__(
        self,
        msg: Message | None = None,
        data: ReadableBuffer | None = None,
        filename: str | None = None,
        password: str | None = None,
        file_obj: IO[str] | None = None,
    ) -> None: ...
    def asbytes(self) -> bytes: ...
    def __hash__(self) -> int: ...
    def get_name(self) -> str: ...
    def get_bits(self) -> int: ...
    def can_sign(self) -> bool: ...
    def sign_ssh_data(self, data: bytes, algorithm: str | None = None) -> Message: ...
    def verify_ssh_sig(self, data: bytes, msg: Message) -> bool: ...



from _typeshed import Incomplete
from typing import ClassVar

from ..core import WesternCalendar

QUEENS_BIRTHDAY_EXCEPTIONS: Incomplete

class CaymanIslands(WesternCalendar):
    include_ash_wednesday: ClassVar[bool]
    include_good_friday: ClassVar[bool]
    include_easter_monday: ClassVar[bool]
    include_boxing_day: ClassVar[bool]
    shift_new_years_day: ClassVar[bool]
    def get_variable_days(self, year): ...
    def get_national_heroes_day(self, year): ...
    def get_discovery_day(self, year): ...
    def get_queens_birthday(self, year): ...
    def get_constitution_day(self, year): ...
    def get_remembrance_day(self, year): ...



import contextlib
import enum
import sys
from collections.abc import Callable, Iterable, Iterator
from typing import Any, ClassVar
from typing_extensions import Self

from pynput._util import AbstractListener

class KeyCode:
    _PLATFORM_EXTENSIONS: ClassVar[Iterable[str]]  # undocumented
    vk: int | None
    char: str | None
    is_dead: bool | None
    combining: str | None
    def __init__(self, vk: str | None = None, char: str | None = None, is_dead: bool = False, **kwargs: str) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __hash__(self) -> int: ...
    def join(self, key: Self) -> Self: ...
    @classmethod
    def from_vk(cls, vk: int, **kwargs: Any) -> Self: ...
    @classmethod
    def from_char(cls, char: str, **kwargs: Any) -> Self: ...
    @classmethod
    def from_dead(cls, char: str, **kwargs: Any) -> Self: ...

class Key(enum.Enum):
    alt: int
    alt_l: int
    alt_r: int
    alt_gr: int
    backspace: int
    caps_lock: int
    cmd: int
    cmd_l: int
    cmd_r: int
    ctrl: int
    ctrl_l: int
    ctrl_r: int
    delete: int
    down: int
    end: int
    enter: int
    esc: int
    f1: int
    f2: int
    f3: int
    f4: int
    f5: int
    f6: int
    f7: int
    f8: int
    f9: int
    f10: int
    f11: int
    f12: int
    f13: int
    f14: int
    f15: int
    f16: int
    f17: int
    f18: int
    f19: int
    f20: int
    if sys.platform == "win32":
        f21: int
        f22: int
        f23: int
        f24: int
    home: int
    left: int
    page_down: int
    page_up: int
    right: int
    shift: int
    shift_l: int
    shift_r: int
    space: int
    tab: int
    up: int
    media_play_pause: int
    media_volume_mute: int
    media_volume_down: int
    media_volume_up: int
    media_previous: int
    media_next: int
    insert: int
    menu: int
    num_lock: int
    pause: int
    print_screen: int
    scroll_lock: int

class Controller:
    _KeyCode: ClassVar[type[KeyCode]]  # undocumented
    _Key: ClassVar[type[Key]]  # undocumented

    if sys.platform == "linux":
        CTRL_MASK: ClassVar[int]
        SHIFT_MASK: ClassVar[int]

    class InvalidKeyException(Exception): ...
    class InvalidCharacterException(Exception): ...

    def __init__(self) -> None: ...
    def press(self, key: str | Key | KeyCode) -> None: ...
    def release(self, key: str | Key | KeyCode) -> None: ...
    def tap(self, key: str | Key | KeyCode) -> None: ...
    def touch(self, key: str | Key | KeyCode, is_press: bool) -> None: ...
    @contextlib.contextmanager
    def pressed(self, *args: str | Key | KeyCode) -> Iterator[None]: ...
    def type(self, string: str) -> None: ...
    @property
    def modifiers(self) -> contextlib.AbstractContextManager[Iterator[set[Key]]]: ...
    @property
    def alt_pressed(self) -> bool: ...
    @property
    def alt_gr_pressed(self) -> bool: ...
    @property
    def ctrl_pressed(self) -> bool: ...
    @property
    def shift_pressed(self) -> bool: ...

class Listener(AbstractListener):
    def __init__(
        self,
        on_press: Callable[[Key | KeyCode | None], None] | None = None,
        on_release: Callable[[Key | KeyCode | None], None] | None = None,
        suppress: bool = False,
        **kwargs: Any,
    ) -> None: ...
    def canonical(self, key: Key | KeyCode) -> Key | KeyCode: ...



from _typeshed import Incomplete
from typing import ClassVar

from ..core import WesternCalendar

class Angola(WesternCalendar):
    include_labour_day: ClassVar[bool]
    labour_day_label: ClassVar[str]
    include_fat_tuesday: ClassVar[bool]
    fat_tuesday_label: ClassVar[str]
    include_good_friday: ClassVar[bool]
    include_easter_sunday: ClassVar[bool]
    include_christmas: ClassVar[bool]
    include_all_souls: ClassVar[bool]
    FIXED_HOLIDAYS: Incomplete



from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

@_dispatch
def core_number(G): ...
@_dispatch
def k_core(G, k: Incomplete | None = None, core_number: Incomplete | None = None): ...
@_dispatch
def k_shell(G, k: Incomplete | None = None, core_number: Incomplete | None = None): ...
@_dispatch
def k_crust(G, k: Incomplete | None = None, core_number: Incomplete | None = None): ...
@_dispatch
def k_corona(G, k, core_number: Incomplete | None = None): ...
@_dispatch
def k_truss(G, k): ...
@_dispatch
def onion_layers(G): ...



from typing import ClassVar

from ..core import WesternCalendar

class Guernsey(WesternCalendar):
    include_easter_monday: ClassVar[bool]
    include_boxing_day: ClassVar[bool]
    shift_new_years_day: ClassVar[bool]
    include_good_friday: ClassVar[bool]
    def get_spring_bank_holiday(self, year): ...
    def get_early_may_bank_holiday(self, year): ...
    def get_summer_bank_holiday(self, year): ...
    def get_liberation_day(self, year): ...
    def get_variable_days(self, year): ...



import abc
from _typeshed import Incomplete
from decimal import Decimal
from typing import Literal, overload
from xml.etree.ElementTree import Element

import qrcode.image.base
from qrcode.image.styles.moduledrawers.base import QRModuleDrawer

class SvgFragmentImage(qrcode.image.base.BaseImageWithDrawer, metaclass=abc.ABCMeta):
    kind: str
    allowed_kinds: Incomplete
    default_drawer_class: type[QRModuleDrawer]
    unit_size: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    @overload
    def units(self, pixels: int | Decimal, text: Literal[False]) -> Decimal: ...
    @overload
    def units(self, pixels: int | Decimal, text: Literal[True] = True) -> str: ...
    def save(self, stream, kind: Incomplete | None = None) -> None: ...
    def to_string(self, **kwargs): ...
    def new_image(self, **kwargs): ...

class SvgImage(SvgFragmentImage, metaclass=abc.ABCMeta):
    background: str | None
    drawer_aliases: qrcode.image.base.DrawerAliases

class SvgPathImage(SvgImage, metaclass=abc.ABCMeta):
    QR_PATH_STYLE: Incomplete
    needs_processing: bool
    path: Element | None
    default_drawer_class: type[QRModuleDrawer]
    drawer_aliases: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def process(self) -> None: ...

class SvgFillImage(SvgImage, metaclass=abc.ABCMeta):
    background: str

class SvgPathFillImage(SvgPathImage, metaclass=abc.ABCMeta):
    background: str



from datetime import date, datetime, timedelta, tzinfo
from time import _TimeTuple, struct_time

class _UTC(tzinfo):
    def dst(self, dt: datetime | None) -> timedelta: ...
    def utcoffset(self, dt: datetime | None) -> timedelta: ...
    def tzname(self, dt: datetime | None) -> str: ...

UTC: _UTC

def timedelta_to_seconds(td: timedelta) -> int: ...

day: timedelta
week: timedelta
hour: timedelta
minute: timedelta
second: timedelta
month: timedelta
year: timedelta

def parse_date(value: str | bytes | None) -> datetime | None: ...
def serialize_date(dt: datetime | date | timedelta | _TimeTuple | struct_time | float | str | bytes) -> str: ...
def parse_date_delta(value: str | bytes | None) -> datetime | None: ...
def serialize_date_delta(value: datetime | date | timedelta | _TimeTuple | struct_time | float | str | bytes) -> str: ...



from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

@_dispatch
def betweenness_centrality_subset(G, sources, targets, normalized: bool = False, weight: Incomplete | None = None): ...
@_dispatch
def edge_betweenness_centrality_subset(G, sources, targets, normalized: bool = False, weight: Incomplete | None = None): ...



from _typeshed import Incomplete, SupportsWrite
from collections.abc import Callable, Mapping, MutableMapping
from typing import Any
from typing_extensions import TypeAlias
from xml.sax import handler
from xml.sax.xmlreader import AttributesImpl, XMLReader

from netaddr.core import Publisher, Subscriber
from netaddr.ip import IPAddress, IPNetwork, IPRange

_IanaInfoKey: TypeAlias = IPAddress | IPNetwork | IPRange

IANA_INFO: dict[str, dict[_IanaInfoKey, dict[str, str]]]

class SaxRecordParser(handler.ContentHandler):
    def __init__(self, callback: Callable[[Mapping[str, object] | None], object] | None = None) -> None: ...
    def startElement(self, name: str, attrs: AttributesImpl) -> None: ...
    def endElement(self, name: str) -> None: ...
    def characters(self, content: str) -> None: ...

class XMLRecordParser(Publisher):
    xmlparser: XMLReader
    fh: Incomplete
    def __init__(self, fh, **kwargs: object) -> None: ...
    def process_record(self, rec: Mapping[str, object]) -> dict[str, str] | None: ...
    def consume_record(self, rec: object) -> None: ...
    def parse(self) -> None: ...
    # Arbitrary attributes are set in __init__ with `self.__dict__.update(kwargs)`
    def __getattr__(self, name: str, /) -> Any: ...

class IPv4Parser(XMLRecordParser):
    def process_record(self, rec: Mapping[str, object]) -> dict[str, str]: ...

class IPv6Parser(XMLRecordParser):
    def process_record(self, rec: Mapping[str, object]) -> dict[str, str]: ...

class IPv6UnicastParser(XMLRecordParser):
    def process_record(self, rec: Mapping[str, object]) -> dict[str, str]: ...

class MulticastParser(XMLRecordParser):
    def normalise_addr(self, addr: str) -> str: ...

class DictUpdater(Subscriber):
    dct: MutableMapping[_IanaInfoKey, Incomplete]
    topic: str
    unique_key: str
    def __init__(self, dct: MutableMapping[_IanaInfoKey, Incomplete], topic: str, unique_key: str) -> None: ...
    def update(self, data) -> None: ...

def load_info() -> None: ...
def pprint_info(fh: SupportsWrite[str] | None = None) -> None: ...
def query(ip_addr: IPAddress) -> dict[str, list[dict[str, str]]]: ...



# Stubs for six.moves.urllib.parse
#
# Note: Commented out items means they weren't implemented at the time.
# Uncomment them when the modules have been added to the typeshed.
# from urllib.parse import splitquery as splitquery
# from urllib.parse import splittag as splittag
# from urllib.parse import splituser as splituser
from urllib.parse import (
    ParseResult as ParseResult,
    SplitResult as SplitResult,
    parse_qs as parse_qs,
    parse_qsl as parse_qsl,
    quote as quote,
    quote_plus as quote_plus,
    unquote as unquote,
    unquote_plus as unquote_plus,
    unquote_to_bytes as unquote_to_bytes,
    urldefrag as urldefrag,
    urlencode as urlencode,
    urljoin as urljoin,
    urlparse as urlparse,
    urlsplit as urlsplit,
    urlunparse as urlunparse,
    urlunsplit as urlunsplit,
    uses_fragment as uses_fragment,
    uses_netloc as uses_netloc,
    uses_params as uses_params,
    uses_query as uses_query,
    uses_relative as uses_relative,
)



from _typeshed import Incomplete, StrOrBytesPath, SupportsItems
from typing import Any
from typing_extensions import Self

class CryptPolicy:
    @classmethod
    def from_path(cls, path, section: str = "passlib", encoding: str = "utf-8"): ...
    @classmethod
    def from_string(cls, source, section: str = "passlib", encoding: str = "utf-8"): ...
    @classmethod
    def from_source(cls, source, _warn: bool = True): ...
    @classmethod
    def from_sources(cls, sources, _warn: bool = True): ...
    def replace(self, *args, **kwds): ...
    def __init__(self, *args, **kwds) -> None: ...
    def has_schemes(self): ...
    def iter_handlers(self): ...
    def schemes(self, resolve: bool = False): ...
    def get_handler(self, name: Incomplete | None = None, category: Incomplete | None = None, required: bool = False): ...
    def get_min_verify_time(self, category: Incomplete | None = None): ...
    def get_options(self, name, category: Incomplete | None = None): ...
    def handler_is_deprecated(self, name, category: Incomplete | None = None): ...
    def iter_config(self, ini: bool = False, resolve: bool = False): ...
    def to_dict(self, resolve: bool = False): ...
    def to_file(self, stream, section: str = "passlib") -> None: ...
    def to_string(self, section: str = "passlib", encoding: Incomplete | None = None): ...

class CryptContext:
    @classmethod
    def from_string(cls, source: str | bytes, section: str = "passlib", encoding: str = "utf-8") -> Self: ...
    @classmethod
    def from_path(cls, path: StrOrBytesPath, section: str = "passlib", encoding: str = "utf-8") -> Self: ...
    def copy(self, **kwds: Any) -> CryptContext: ...
    def using(self, **kwds: Any) -> CryptContext: ...
    def replace(self, **kwds): ...
    def __init__(self, schemes: Incomplete | None = None, policy=..., _autoload: bool = True, **kwds) -> None: ...
    policy: CryptPolicy
    def load_path(
        self, path: StrOrBytesPath, update: bool = False, section: str = "passlib", encoding: str = "utf-8"
    ) -> None: ...
    def load(
        self,
        source: str | bytes | SupportsItems[str, Any] | CryptContext,
        update: bool = False,
        section: str = "passlib",
        encoding: str = "utf-8",
    ) -> None: ...
    def update(self, *args: Any, **kwds: Any) -> None: ...
    def schemes(self, resolve: bool = False, category: Incomplete | None = None, unconfigured: bool = False): ...
    def default_scheme(self, category: Incomplete | None = None, resolve: bool = False, unconfigured: bool = False): ...
    def handler(self, scheme: Incomplete | None = None, category: Incomplete | None = None, unconfigured: bool = False): ...
    @property
    def context_kwds(self): ...
    def to_dict(self, resolve: bool = False) -> dict[str, Any]: ...
    def to_string(self, section: str = "passlib") -> str: ...
    mvt_estimate_max_samples: int
    mvt_estimate_min_samples: int
    mvt_estimate_max_time: int
    mvt_estimate_resolution: float
    harden_verify: Any
    min_verify_time: int
    def reset_min_verify_time(self) -> None: ...
    def needs_update(
        self, hash: str | bytes, scheme: str | None = None, category: str | None = None, secret: str | bytes | None = None
    ) -> bool: ...
    def hash_needs_update(self, hash, scheme: Incomplete | None = None, category: Incomplete | None = None): ...
    def genconfig(self, scheme: Incomplete | None = None, category: Incomplete | None = None, **settings): ...
    def genhash(self, secret, config, scheme: Incomplete | None = None, category: Incomplete | None = None, **kwds): ...
    def identify(
        self, hash, category: Incomplete | None = None, resolve: bool = False, required: bool = False, unconfigured: bool = False
    ): ...
    def hash(self, secret: str | bytes, scheme: str | None = None, category: str | None = None, **kwds: Any) -> str: ...
    def encrypt(self, *args, **kwds): ...
    def verify(
        self, secret: str | bytes, hash: str | bytes | None, scheme: str | None = None, category: str | None = None, **kwds: Any
    ) -> bool: ...
    def verify_and_update(
        self, secret: str | bytes, hash: str | bytes | None, scheme: str | None = None, category: str | None = None, **kwds: Any
    ) -> tuple[bool, str | None]: ...
    def dummy_verify(self, elapsed: int = 0): ...
    def is_enabled(self, hash: str | bytes) -> bool: ...
    def disable(self, hash: str | bytes | None = None) -> str: ...
    def enable(self, hash: str | bytes) -> str: ...

class LazyCryptContext(CryptContext):
    def __init__(self, schemes: Incomplete | None = None, **kwds) -> None: ...
    def __getattribute__(self, attr: str) -> Any: ...



from collections.abc import Callable
from typing import Any, Generic, Literal, TypeVar, overload
from typing_extensions import ParamSpec

from uwsgi import _RPCCallable

_T = TypeVar("_T")
_T2 = TypeVar("_T2")
_SR = TypeVar("_SR", bound=Literal[0, -1, -2] | None)
_SignalCallbackT = TypeVar("_SignalCallbackT", bound=Callable[[int], Any])
_RPCCallableT = TypeVar("_RPCCallableT", bound=_RPCCallable)
_P = ParamSpec("_P")
_P2 = ParamSpec("_P2")

spooler_functions: dict[str, Callable[..., Literal[0, -1, -2] | None]]
mule_functions: dict[str, Callable[..., Any]]
postfork_chain: list[Callable[[], None]]

def get_free_signal() -> int: ...
def manage_spool_request(vars: dict[bytes, Any]) -> Literal[0, -1, -2]: ...
def postfork_chain_hook() -> None: ...

class postfork(Generic[_P, _T]):
    wid: int
    f: Callable[_P, _T] | None
    @overload
    def __init__(self: postfork[..., Any], f: int) -> None: ...
    @overload
    def __init__(self: postfork[_P, _T], f: Callable[_P, _T]) -> None: ...
    @overload
    def __call__(self, f: Callable[_P2, _T2], /) -> postfork[_P2, _T2]: ...
    @overload
    def __call__(self, *args: _P.args, **kwargs: _P.kwargs) -> _T: ...

class _spoolraw(Generic[_P, _SR]):
    f: Callable[_P, _SR]
    pass_arguments: bool
    base_dict: dict[str, Any]
    def __init__(self, f: Callable[_P, _SR], pass_arguments: bool) -> None: ...
    def __call__(self, *args: _P.args, **kwargs: _P.kwargs) -> _SR: ...
    def spool(self, *args: _P.args, **kwargs: _P.kwargs) -> _SR: ...

class _spool(_spoolraw[_P, _SR]): ...
class _spoolforever(_spoolraw[_P, _SR]): ...

@overload
def spool_decorate(
    f: Callable[_P, _SR], pass_arguments: bool = False, _class: type[_spoolraw[_P, _SR]] = ...
) -> _spoolraw[_P, _SR]: ...
@overload
def spool_decorate(
    f: None = None, pass_arguments: bool = False, _class: type[_spoolraw[..., Any]] = ...
) -> Callable[[Callable[_P, _SR]], _spoolraw[_P, _SR]]: ...
@overload
def spoolraw(f: Callable[_P, _SR], pass_arguments: bool = False) -> _spoolraw[_P, _SR]: ...
@overload
def spoolraw(f: None = None, pass_arguments: bool = False) -> Callable[[Callable[_P, _SR]], _spoolraw[_P, _SR]]: ...
@overload
def spool(f: Callable[_P, _SR], pass_arguments: bool = False) -> _spool[_P, _SR]: ...
@overload
def spool(f: None = None, pass_arguments: bool = False) -> Callable[[Callable[_P, _SR]], _spool[_P, _SR]]: ...
@overload
def spoolforever(f: Callable[_P, _SR], pass_arguments: bool = False) -> _spoolforever[_P, _SR]: ...
@overload
def spoolforever(f: None = None, pass_arguments: bool = False) -> Callable[[Callable[_P, _SR]], _spoolforever[_P, _SR]]: ...

class mulefunc(Generic[_P, _T]):
    fname: str | None
    mule: int
    @overload
    def __init__(self: mulefunc[..., Any], f: int) -> None: ...
    @overload
    def __init__(self: mulefunc[_P, _T], f: Callable[_P, _T]) -> None: ...
    def real_call(self, *args: _P.args, **kwargs: _P.kwargs) -> None: ...
    @overload
    def __call__(self, f: Callable[_P2, _T2], /) -> mulefunc[_P2, _T2]: ...
    @overload
    def __call__(self, *args: _P.args, **kwargs: _P.kwargs) -> _T: ...

def mule_msg_dispatcher(message: bytes) -> Any: ...

class rpc:
    name: str
    def __init__(self, name: str) -> None: ...
    def __call__(self, f: _RPCCallableT) -> _RPCCallableT: ...

class farm_loop:
    f: Callable[[bytes], Any]
    farm: str | None
    def __init__(self, f: Callable[[bytes], Any], farm: str | None) -> None: ...
    def __call__(self) -> None: ...

class farm:
    name: str
    def __init__(self, name: str | None = None, **kwargs: Any) -> None: ...
    def __call__(self, f: Callable[[bytes], Any]) -> None: ...

class mule_brain:
    f: Callable[[], Any]
    num: int
    def __init__(self, f: Callable[[], Any], num: int) -> None: ...
    def __call__(self) -> None: ...

class mule_brainloop(mule_brain): ...

class mule:
    num: int
    def __init__(self, num: int) -> None: ...
    def __call__(self, f: Callable[[], Any]) -> None: ...

class muleloop(mule): ...

class mulemsg_loop:
    f: Callable[[bytes], Any]
    num: int
    def __init__(self, f: Callable[[bytes], Any], num: int) -> None: ...
    def __call__(self) -> None: ...

class mulemsg:
    num: int
    def __init__(self, num: int) -> None: ...
    def __call__(self, f: Callable[[bytes], Any]) -> None: ...

class signal:
    num: int
    target: str
    def __init__(self, num: int, *, target: str = "", **kwargs: Any) -> None: ...
    def __call__(self, f: _SignalCallbackT) -> _SignalCallbackT: ...

class timer:
    num: int
    secs: int
    target: str
    def __init__(self, secs: int, *, signum: int = ..., target: str = "", **kwargs: Any) -> None: ...
    def __call__(self, f: _SignalCallbackT) -> _SignalCallbackT: ...

class cron:
    num: int
    minute: int
    hour: int
    day: int
    month: int
    dayweek: int
    target: str
    def __init__(
        self, minute: int, hour: int, day: int, month: int, dayweek: int, *, signum: int = ..., target: str = "", **kwargs: Any
    ) -> None: ...
    def __call__(self, f: _SignalCallbackT) -> _SignalCallbackT: ...

class rbtimer:
    num: int
    secs: int
    target: str
    def __init__(self, secs: int, *, signum: int = ..., target: str = "", **kwargs: Any) -> None: ...
    def __call__(self, f: _SignalCallbackT) -> _SignalCallbackT: ...

class filemon:
    num: int
    fsobj: str
    target: str
    def __init__(self, fsobj: str, *, signum: int = ..., target: str = "", **kwargs: Any) -> None: ...
    def __call__(self, f: _SignalCallbackT) -> _SignalCallbackT: ...

class lock(Generic[_P, _T]):
    f: Callable[_P, _T]
    def __init__(self, f: Callable[_P, _T]) -> None: ...
    def __call__(self, *args: _P.args, **kwargs: _P.kwargs) -> _T: ...

# FIXME: Technically this only allows positional arguments, but there is not really
#        an adequate way yet to express this, once bound on ParamSpec does something
#        we could probably enforce this
class thread(Generic[_P, _T]):
    f: Callable[_P, _T]
    def __init__(self, f: Callable[_P, _T]) -> None: ...
    def __call__(self, *args: _P.args, **kwargs: _P.kwargs) -> Callable[_P, _T]: ...

class harakiri:
    s: int
    def __init__(self, seconds: int) -> None: ...
    def __call__(self, f: Callable[_P, _T]) -> Callable[_P, _T]: ...



from networkx.utils.backends import _dispatch

@_dispatch
def maximum_independent_set(G): ...
@_dispatch
def max_clique(G): ...
@_dispatch
def clique_removal(G): ...
@_dispatch
def large_clique_size(G): ...



from _typeshed import Incomplete
from typing import Any

class Plugin:
    capability: Any
    @classmethod
    def is_capable(cls, requested_capability): ...

def get_plugin(cls, requested_capability: Incomplete | None = None): ...
def load_plugins(config): ...



from _typeshed import Incomplete

class TemplateSummarySummaryLabelMappings:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        status: Incomplete | None = None,
        resource_template_meta_name: Incomplete | None = None,
        resource_name: Incomplete | None = None,
        resource_id: Incomplete | None = None,
        resource_type: Incomplete | None = None,
        label_template_meta_name: Incomplete | None = None,
        label_name: Incomplete | None = None,
        label_id: Incomplete | None = None,
    ) -> None: ...
    @property
    def status(self): ...
    @status.setter
    def status(self, status) -> None: ...
    @property
    def resource_template_meta_name(self): ...
    @resource_template_meta_name.setter
    def resource_template_meta_name(self, resource_template_meta_name) -> None: ...
    @property
    def resource_name(self): ...
    @resource_name.setter
    def resource_name(self, resource_name) -> None: ...
    @property
    def resource_id(self): ...
    @resource_id.setter
    def resource_id(self, resource_id) -> None: ...
    @property
    def resource_type(self): ...
    @resource_type.setter
    def resource_type(self, resource_type) -> None: ...
    @property
    def label_template_meta_name(self): ...
    @label_template_meta_name.setter
    def label_template_meta_name(self, label_template_meta_name) -> None: ...
    @property
    def label_name(self): ...
    @label_name.setter
    def label_name(self, label_name) -> None: ...
    @property
    def label_id(self): ...
    @label_id.setter
    def label_id(self, label_id) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...
